Class: Google::Cloud::Kms::V1::ApproveSingleTenantHsmInstanceProposalRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Kms::V1::ApproveSingleTenantHsmInstanceProposalRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/kms/v1/hsm_management.rb
Overview
Request message for HsmManagement.ApproveSingleTenantHsmInstanceProposal.
Defined Under Namespace
Classes: QuorumReply, RequiredActionQuorumReply
Instance Attribute Summary collapse
-
#name ⇒ ::String
Required.
-
#quorum_reply ⇒ ::Google::Cloud::Kms::V1::ApproveSingleTenantHsmInstanceProposalRequest::QuorumReply
Required.
-
#required_action_quorum_reply ⇒ ::Google::Cloud::Kms::V1::ApproveSingleTenantHsmInstanceProposalRequest::RequiredActionQuorumReply
Required.
Instance Attribute Details
#name ⇒ ::String
Returns Required. The name of the SingleTenantHsmInstanceProposal to approve.
748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 |
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 748 class ApproveSingleTenantHsmInstanceProposalRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The reply to # {::Google::Cloud::Kms::V1::SingleTenantHsmInstanceProposal::QuorumParameters QuorumParameters} # for approving the proposal. # @!attribute [rw] challenge_replies # @return [::Array<::Google::Cloud::Kms::V1::ChallengeReply>] # Required. The challenge replies to approve the proposal. Challenge # replies can be sent across multiple requests. The proposal will be # approved when # {::Google::Cloud::Kms::V1::SingleTenantHsmInstanceProposal::QuorumParameters#required_approver_count required_approver_count} # challenge replies are provided. class QuorumReply include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The reply to # {::Google::Cloud::Kms::V1::SingleTenantHsmInstanceProposal::RequiredActionQuorumParameters RequiredActionQuorumParameters} # for approving the proposal. # @!attribute [rw] required_challenge_replies # @return [::Array<::Google::Cloud::Kms::V1::ChallengeReply>] # Required. All required challenges must be signed for the proposal to be # approved. These can be sent across multiple requests. # @!attribute [rw] quorum_challenge_replies # @return [::Array<::Google::Cloud::Kms::V1::ChallengeReply>] # Required. Quorum members' signed challenge replies. These can be provided # across multiple requests. The proposal will be approved when # {::Google::Cloud::Kms::V1::SingleTenantHsmInstanceProposal::RequiredActionQuorumParameters#required_approver_count required_approver_count} # quorum_challenge_replies are provided and when all # required_challenge_replies are provided. class RequiredActionQuorumReply include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#quorum_reply ⇒ ::Google::Cloud::Kms::V1::ApproveSingleTenantHsmInstanceProposalRequest::QuorumReply
Returns Required. The reply to QuorumParameters for approving the proposal.
Note: The following fields are mutually exclusive: quorum_reply, required_action_quorum_reply. If a field in that set is populated, all other fields in the set will automatically be cleared.
748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 |
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 748 class ApproveSingleTenantHsmInstanceProposalRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The reply to # {::Google::Cloud::Kms::V1::SingleTenantHsmInstanceProposal::QuorumParameters QuorumParameters} # for approving the proposal. # @!attribute [rw] challenge_replies # @return [::Array<::Google::Cloud::Kms::V1::ChallengeReply>] # Required. The challenge replies to approve the proposal. Challenge # replies can be sent across multiple requests. The proposal will be # approved when # {::Google::Cloud::Kms::V1::SingleTenantHsmInstanceProposal::QuorumParameters#required_approver_count required_approver_count} # challenge replies are provided. class QuorumReply include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The reply to # {::Google::Cloud::Kms::V1::SingleTenantHsmInstanceProposal::RequiredActionQuorumParameters RequiredActionQuorumParameters} # for approving the proposal. # @!attribute [rw] required_challenge_replies # @return [::Array<::Google::Cloud::Kms::V1::ChallengeReply>] # Required. All required challenges must be signed for the proposal to be # approved. These can be sent across multiple requests. # @!attribute [rw] quorum_challenge_replies # @return [::Array<::Google::Cloud::Kms::V1::ChallengeReply>] # Required. Quorum members' signed challenge replies. These can be provided # across multiple requests. The proposal will be approved when # {::Google::Cloud::Kms::V1::SingleTenantHsmInstanceProposal::RequiredActionQuorumParameters#required_approver_count required_approver_count} # quorum_challenge_replies are provided and when all # required_challenge_replies are provided. class RequiredActionQuorumReply include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#required_action_quorum_reply ⇒ ::Google::Cloud::Kms::V1::ApproveSingleTenantHsmInstanceProposalRequest::RequiredActionQuorumReply
Returns Required. The reply to RequiredActionQuorumParameters for approving the proposal.
Note: The following fields are mutually exclusive: required_action_quorum_reply, quorum_reply. If a field in that set is populated, all other fields in the set will automatically be cleared.
748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 |
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 748 class ApproveSingleTenantHsmInstanceProposalRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The reply to # {::Google::Cloud::Kms::V1::SingleTenantHsmInstanceProposal::QuorumParameters QuorumParameters} # for approving the proposal. # @!attribute [rw] challenge_replies # @return [::Array<::Google::Cloud::Kms::V1::ChallengeReply>] # Required. The challenge replies to approve the proposal. Challenge # replies can be sent across multiple requests. The proposal will be # approved when # {::Google::Cloud::Kms::V1::SingleTenantHsmInstanceProposal::QuorumParameters#required_approver_count required_approver_count} # challenge replies are provided. class QuorumReply include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The reply to # {::Google::Cloud::Kms::V1::SingleTenantHsmInstanceProposal::RequiredActionQuorumParameters RequiredActionQuorumParameters} # for approving the proposal. # @!attribute [rw] required_challenge_replies # @return [::Array<::Google::Cloud::Kms::V1::ChallengeReply>] # Required. All required challenges must be signed for the proposal to be # approved. These can be sent across multiple requests. # @!attribute [rw] quorum_challenge_replies # @return [::Array<::Google::Cloud::Kms::V1::ChallengeReply>] # Required. Quorum members' signed challenge replies. These can be provided # across multiple requests. The proposal will be approved when # {::Google::Cloud::Kms::V1::SingleTenantHsmInstanceProposal::RequiredActionQuorumParameters#required_approver_count required_approver_count} # quorum_challenge_replies are provided and when all # required_challenge_replies are provided. class RequiredActionQuorumReply include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |