Module: Google::Cloud::Kms::V1::AutokeyAdmin
- Defined in:
- lib/google/cloud/kms/v1/autokey_admin.rb,
lib/google/cloud/kms/v1/autokey_admin/rest.rb,
lib/google/cloud/kms/v1/autokey_admin/paths.rb,
lib/google/cloud/kms/v1/autokey_admin/client.rb,
lib/google/cloud/kms/v1/autokey_admin/credentials.rb,
lib/google/cloud/kms/v1/autokey_admin/rest/client.rb,
lib/google/cloud/kms/v1/autokey_admin/rest/service_stub.rb
Overview
Provides interfaces for managing Cloud KMS Autokey folder-level or project-level configurations. A configuration is inherited by all descendent folders and projects. A configuration at a folder or project overrides any other configurations in its ancestry. Setting a configuration on a folder is a prerequisite for Cloud KMS Autokey, so that users working in a descendant project can request provisioned CryptoKeys, ready for Customer Managed Encryption Key (CMEK) use, on-demand when using the dedicated key project mode. This is not required when using the delegated key management mode for same-project keys.
To load this service and instantiate a REST client:
require "google/cloud/kms/v1/autokey_admin/rest"
client = ::Google::Cloud::Kms::V1::AutokeyAdmin::Rest::Client.new
Defined Under Namespace
Modules: Paths, Rest Classes: Client, Credentials