Class: Google::Cloud::Kms::V1::AutokeyAdmin::Client
- Inherits:
-
Object
- Object
- Google::Cloud::Kms::V1::AutokeyAdmin::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/kms/v1/autokey_admin/client.rb
Overview
Client for the AutokeyAdmin service.
Provides interfaces for managing Cloud KMS Autokey folder-level or project-level configurations. A configuration is inherited by all descendent folders and projects. A configuration at a folder or project overrides any other configurations in its ancestry. Setting a configuration on a folder is a prerequisite for Cloud KMS Autokey, so that users working in a descendant project can request provisioned CryptoKeys, ready for Customer Managed Encryption Key (CMEK) use, on-demand when using the dedicated key project mode. This is not required when using the delegated key management mode for same-project keys.
Defined Under Namespace
Classes: Configuration
Instance Attribute Summary collapse
-
#iam_policy_client ⇒ Google::Iam::V1::IAMPolicy::Client
readonly
Get the associated client for mix-in of the IAMPolicy.
-
#location_client ⇒ Google::Cloud::Location::Locations::Client
readonly
Get the associated client for mix-in of the Locations.
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the AutokeyAdmin Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the AutokeyAdmin Client instance.
-
#get_autokey_config(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Kms::V1::AutokeyConfig
Returns the AutokeyConfig for a folder or project.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new AutokeyAdmin client object.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#show_effective_autokey_config(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Kms::V1::ShowEffectiveAutokeyConfigResponse
Returns the effective Cloud KMS Autokey configuration for a given project.
-
#universe_domain ⇒ String
The effective universe domain.
-
#update_autokey_config(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Kms::V1::AutokeyConfig
Updates the AutokeyConfig for a folder or a project.
Methods included from Paths
#autokey_config_path, #project_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new AutokeyAdmin client object.
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/google/cloud/kms/v1/autokey_admin/client.rb', line 150 def initialize # These require statements are intentionally placed here to initialize # the gRPC module only when it's required. # See https://github.com/googleapis/toolkit/issues/446 require "gapic/grpc" require "google/cloud/kms/v1/autokey_admin_services_pb" # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @autokey_admin_stub = ::Gapic::ServiceStub.new( ::Google::Cloud::Kms::V1::AutokeyAdmin::Stub, credentials: credentials, endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, channel_args: @config.channel_args, interceptors: @config.interceptors, channel_pool_config: @config.channel_pool, logger: @config.logger ) @autokey_admin_stub.stub_logger&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end @location_client = Google::Cloud::Location::Locations::Client.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @autokey_admin_stub.endpoint config.universe_domain = @autokey_admin_stub.universe_domain config.logger = @autokey_admin_stub.logger if config.respond_to? :logger= end @iam_policy_client = Google::Iam::V1::IAMPolicy::Client.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @autokey_admin_stub.endpoint config.universe_domain = @autokey_admin_stub.universe_domain config.logger = @autokey_admin_stub.logger if config.respond_to? :logger= end end |
Instance Attribute Details
#iam_policy_client ⇒ Google::Iam::V1::IAMPolicy::Client (readonly)
Get the associated client for mix-in of the IAMPolicy.
229 230 231 |
# File 'lib/google/cloud/kms/v1/autokey_admin/client.rb', line 229 def iam_policy_client @iam_policy_client end |
#location_client ⇒ Google::Cloud::Location::Locations::Client (readonly)
Get the associated client for mix-in of the Locations.
222 223 224 |
# File 'lib/google/cloud/kms/v1/autokey_admin/client.rb', line 222 def location_client @location_client end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the AutokeyAdmin Client class.
See Configuration for a description of the configuration fields.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/google/cloud/kms/v1/autokey_admin/client.rb', line 73 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "Kms", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.rpcs.update_autokey_config.timeout = 60.0 default_config.rpcs.update_autokey_config.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14, 4] } default_config.rpcs.get_autokey_config.timeout = 60.0 default_config.rpcs.get_autokey_config.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14, 4] } default_config.rpcs.show_effective_autokey_config.timeout = 60.0 default_config.rpcs.show_effective_autokey_config.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14, 4] } default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the AutokeyAdmin Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
120 121 122 123 |
# File 'lib/google/cloud/kms/v1/autokey_admin/client.rb', line 120 def configure yield @config if block_given? @config end |
#get_autokey_config(request, options = nil) ⇒ ::Google::Cloud::Kms::V1::AutokeyConfig #get_autokey_config(name: nil) ⇒ ::Google::Cloud::Kms::V1::AutokeyConfig
Returns the AutokeyConfig for a folder or project.
385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 |
# File 'lib/google/cloud/kms/v1/autokey_admin/client.rb', line 385 def get_autokey_config request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Kms::V1::GetAutokeyConfigRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_autokey_config..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Kms::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_autokey_config.timeout, metadata: , retry_policy: @config.rpcs.get_autokey_config.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @autokey_admin_stub.call_rpc :get_autokey_config, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
236 237 238 |
# File 'lib/google/cloud/kms/v1/autokey_admin/client.rb', line 236 def logger @autokey_admin_stub.logger end |
#show_effective_autokey_config(request, options = nil) ⇒ ::Google::Cloud::Kms::V1::ShowEffectiveAutokeyConfigResponse #show_effective_autokey_config(parent: nil) ⇒ ::Google::Cloud::Kms::V1::ShowEffectiveAutokeyConfigResponse
Returns the effective Cloud KMS Autokey configuration for a given project.
472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 |
# File 'lib/google/cloud/kms/v1/autokey_admin/client.rb', line 472 def show_effective_autokey_config request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Kms::V1::ShowEffectiveAutokeyConfigRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.show_effective_autokey_config..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Kms::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.show_effective_autokey_config.timeout, metadata: , retry_policy: @config.rpcs.show_effective_autokey_config.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @autokey_admin_stub.call_rpc :show_effective_autokey_config, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#universe_domain ⇒ String
The effective universe domain
130 131 132 |
# File 'lib/google/cloud/kms/v1/autokey_admin/client.rb', line 130 def universe_domain @autokey_admin_stub.universe_domain end |
#update_autokey_config(request, options = nil) ⇒ ::Google::Cloud::Kms::V1::AutokeyConfig #update_autokey_config(autokey_config: nil, update_mask: nil) ⇒ ::Google::Cloud::Kms::V1::AutokeyConfig
Updates the AutokeyConfig for a folder
or a project. The caller must have both cloudkms.autokeyConfigs.update
permission on the parent folder and cloudkms.cryptoKeys.setIamPolicy
permission on the provided key project. A
KeyHandle creation in the folder's
descendant projects will use this configuration to determine where to
create the resulting CryptoKey.
297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'lib/google/cloud/kms/v1/autokey_admin/client.rb', line 297 def update_autokey_config request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Kms::V1::UpdateAutokeyConfigRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_autokey_config..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Kms::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.autokey_config&.name header_params["autokey_config.name"] = request.autokey_config.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.update_autokey_config.timeout, metadata: , retry_policy: @config.rpcs.update_autokey_config.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @autokey_admin_stub.call_rpc :update_autokey_config, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |