Module: Google::Cloud::Kms::V1::AutokeyConfig::KeyProjectResolutionMode
- Defined in:
- proto_docs/google/cloud/kms/v1/autokey_admin.rb
Overview
Defines the resolution mode enum for the key project. The KeyProjectResolutionMode determines the mechanism by which AutokeyConfig identifies a key_project at its specific configuration node. This parameter also determines if Autokey can be used within this project or folder.
Constant Summary collapse
- KEY_PROJECT_RESOLUTION_MODE_UNSPECIFIED =
Default value. KeyProjectResolutionMode when not specified will act as
DEDICATED_KEY_PROJECT. 0- DEDICATED_KEY_PROJECT =
Keys are created in a dedicated project specified by
key_project. 1- RESOURCE_PROJECT =
Keys are created in the same project as the resource requesting the key. The
key_projectmust not be set when this mode is used. 2- DISABLED =
Disables the AutokeyConfig. When this mode is set, any AutokeyConfig from higher levels in the resource hierarchy are ignored for this resource and its descendants. This setting can be overridden by a more specific configuration at a lower level. For example, if Autokey is disabled on a folder, it can be re-enabled on a sub-folder or project within that folder by setting a different mode (e.g., DEDICATED_KEY_PROJECT or RESOURCE_PROJECT).
3