Class: Google::Cloud::Kms::V1::CreateCryptoKeyRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Kms::V1::CreateCryptoKeyRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/kms/v1/service.rb
Overview
Request message for KeyManagementService.CreateCryptoKey.
Instance Attribute Summary collapse
-
#crypto_key ⇒ ::Google::Cloud::Kms::V1::CryptoKey
Required.
-
#crypto_key_id ⇒ ::String
Required.
-
#parent ⇒ ::String
Required.
-
#skip_initial_version_creation ⇒ ::Boolean
If set to true, the request will create a CryptoKey without any CryptoKeyVersions.
-
#trusted_wrapping_enabled ⇒ ::Boolean
Optional.
Instance Attribute Details
#crypto_key ⇒ ::Google::Cloud::Kms::V1::CryptoKey
Returns Required. A CryptoKey with initial field values.
455 456 457 458 |
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 455 class CreateCryptoKeyRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#crypto_key_id ⇒ ::String
Returns Required. It must be unique within a KeyRing and match the regular
expression [a-zA-Z0-9_-]{1,63}.
455 456 457 458 |
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 455 class CreateCryptoKeyRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The name of the KeyRing associated with the CryptoKeys.
455 456 457 458 |
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 455 class CreateCryptoKeyRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#skip_initial_version_creation ⇒ ::Boolean
Returns If set to true, the request will create a CryptoKey without any CryptoKeyVersions. You must manually call CreateCryptoKeyVersion or ImportCryptoKeyVersion before you can use this CryptoKey.
455 456 457 458 |
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 455 class CreateCryptoKeyRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#trusted_wrapping_enabled ⇒ ::Boolean
Returns Optional. Whether trusted wrapping will be enabled on the first CryptoKeyVersions created for this CryptoKey. This field is only supported for keys with CryptoKeyVersionTemplate.protection_level HSM_SINGLE_TENANT. This field is supported for all CryptoKeyPurposes except ENCRYPT_DECRYPT.
455 456 457 458 |
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 455 class CreateCryptoKeyRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |