Class: Google::Cloud::Kms::V1::CreateSingleTenantHsmInstanceProposalRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/kms/v1/hsm_management.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#parent::String

Returns Required. The name of the SingleTenantHsmInstance associated with the SingleTenantHsmInstanceProposals.

Returns:



675
676
677
678
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 675

class CreateSingleTenantHsmInstanceProposalRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#single_tenant_hsm_instance_proposal::Google::Cloud::Kms::V1::SingleTenantHsmInstanceProposal

Returns Required. The SingleTenantHsmInstanceProposal to create.



675
676
677
678
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 675

class CreateSingleTenantHsmInstanceProposalRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#single_tenant_hsm_instance_proposal_id::String

Returns Optional. It must be unique within a location and match the regular expression [a-zA-Z0-9_-]{1,63}.

Returns:

  • (::String)

    Optional. It must be unique within a location and match the regular expression [a-zA-Z0-9_-]{1,63}.



675
676
677
678
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 675

class CreateSingleTenantHsmInstanceProposalRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end