Class: Google::Cloud::Kms::V1::CreateSingleTenantHsmInstanceRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/kms/v1/hsm_management.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#parent::String

Returns Required. The resource name of the location associated with the SingleTenantHsmInstance, in the format projects/*/locations/*.

Returns:

  • (::String)

    Required. The resource name of the location associated with the SingleTenantHsmInstance, in the format projects/*/locations/*.



645
646
647
648
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 645

class CreateSingleTenantHsmInstanceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#single_tenant_hsm_instance::Google::Cloud::Kms::V1::SingleTenantHsmInstance

Returns Required. An SingleTenantHsmInstance with initial field values.

Returns:



645
646
647
648
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 645

class CreateSingleTenantHsmInstanceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#single_tenant_hsm_instance_id::String

Returns Optional. It must be unique within a location and match the regular expression [a-zA-Z0-9_-]{1,63}.

Returns:

  • (::String)

    Optional. It must be unique within a location and match the regular expression [a-zA-Z0-9_-]{1,63}.



645
646
647
648
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 645

class CreateSingleTenantHsmInstanceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end