Class: Google::Cloud::Kms::V1::DecapsulateRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/kms/v1/service.rb

Overview

Request message for KeyManagementService.Decapsulate.

Instance Attribute Summary collapse

Instance Attribute Details

#ciphertext::String

Returns Required. The ciphertext produced from encapsulation with the named CryptoKeyVersion public key(s).

Returns:

  • (::String)

    Required. The ciphertext produced from encapsulation with the named CryptoKeyVersion public key(s).



1220
1221
1222
1223
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 1220

class DecapsulateRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ciphertext_crc32c::Google::Protobuf::Int64Value

Returns Optional. A CRC32C checksum of the DecapsulateRequest.ciphertext. If specified, KeyManagementService will verify the integrity of the received DecapsulateRequest.ciphertext using this checksum. KeyManagementService will report an error if the checksum verification fails. If you receive a checksum error, your client should verify that CRC32C(DecapsulateRequest.ciphertext) is equal to DecapsulateRequest.ciphertext_crc32c, and if so, perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non-negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type.

Returns:



1220
1221
1222
1223
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 1220

class DecapsulateRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The resource name of the CryptoKeyVersion to use for decapsulation.

Returns:

  • (::String)

    Required. The resource name of the CryptoKeyVersion to use for decapsulation.



1220
1221
1222
1223
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 1220

class DecapsulateRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end