Class: Google::Cloud::Kms::V1::DecapsulateResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/kms/v1/service.rb

Overview

Response message for KeyManagementService.Decapsulate.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns The resource name of the CryptoKeyVersion used for decapsulation. Check this field to verify that the intended resource was used for decapsulation.

Returns:

  • (::String)

    The resource name of the CryptoKeyVersion used for decapsulation. Check this field to verify that the intended resource was used for decapsulation.



1807
1808
1809
1810
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 1807

class DecapsulateResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#protection_level::Google::Cloud::Kms::V1::ProtectionLevel

Returns The ProtectionLevel of the CryptoKeyVersion used in decapsulation.

Returns:



1807
1808
1809
1810
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 1807

class DecapsulateResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#shared_secret::String

Returns The decapsulated shared_secret originally encapsulated with the matching public key.

Returns:

  • (::String)

    The decapsulated shared_secret originally encapsulated with the matching public key.



1807
1808
1809
1810
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 1807

class DecapsulateResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#shared_secret_crc32c::Integer

Returns Integrity verification field. A CRC32C checksum of the returned DecapsulateResponse.shared_secret. An integrity check of DecapsulateResponse.shared_secret can be performed by computing the CRC32C checksum of DecapsulateResponse.shared_secret and comparing your results to this field. Discard the response in case of non-matching checksum values, and perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: receiving this response message indicates that KeyManagementService is able to successfully decrypt the ciphertext. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non-negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type.

Returns:

  • (::Integer)

    Integrity verification field. A CRC32C checksum of the returned DecapsulateResponse.shared_secret. An integrity check of DecapsulateResponse.shared_secret can be performed by computing the CRC32C checksum of DecapsulateResponse.shared_secret and comparing your results to this field. Discard the response in case of non-matching checksum values, and perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: receiving this response message indicates that KeyManagementService is able to successfully decrypt the ciphertext. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non-negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type.



1807
1808
1809
1810
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 1807

class DecapsulateResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#verified_ciphertext_crc32c::Boolean

Returns Integrity verification field. A flag indicating whether DecapsulateRequest.ciphertext_crc32c was received by KeyManagementService and used for the integrity verification of the ciphertext. A false value of this field indicates either that DecapsulateRequest.ciphertext_crc32c was left unset or that it was not delivered to KeyManagementService. If you've set DecapsulateRequest.ciphertext_crc32c but this field is still false, discard the response and perform a limited number of retries.

Returns:



1807
1808
1809
1810
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 1807

class DecapsulateResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end