Class: Google::Cloud::Kms::V1::DeleteCryptoKeyMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/kms/v1/service.rb

Overview

Represents the metadata of the KeyManagementService.DeleteCryptoKey long-running operation.

Instance Attribute Summary collapse

Instance Attribute Details

#retired_resource::String (readonly)

Returns Output only. The resource name of the RetiredResource created as a result of this operation, in the format projects/*/locations/*/retiredResources/*.

Returns:

  • (::String)

    Output only. The resource name of the RetiredResource created as a result of this operation, in the format projects/*/locations/*/retiredResources/*.



2027
2028
2029
2030
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 2027

class DeleteCryptoKeyMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end