Class: Google::Cloud::Kms::V1::ExportTrustedKeyWrappedCryptoKeyVersionResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/kms/v1/service.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#wrapped_key::String

Returns The wrapped key material.

Returns:

  • (::String)

    The wrapped key material.



695
696
697
698
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 695

class ExportTrustedKeyWrappedCryptoKeyVersionResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#wrapped_key_crc32c::Google::Protobuf::Int64Value

Returns Integrity verification field. A CRC32C checksum of the returned ExportTrustedKeyWrappedCryptoKeyVersionResponse.wrapped_key. An integrity check of ExportTrustedKeyWrappedCryptoKeyVersionResponse.wrapped_key can be performed by computing the CRC32C checksum of ExportTrustedKeyWrappedCryptoKeyVersionResponse.wrapped_key and comparing your results to this field. Discard the response in case of non-matching checksum values, and perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non-negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type.

Returns:



695
696
697
698
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 695

class ExportTrustedKeyWrappedCryptoKeyVersionResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end