Class: Google::Cloud::Kms::V1::HsmManagement::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/kms/v1/hsm_management/client.rb

Overview

Client for the HsmManagement service.

Google Cloud HSM Management Service

Provides interfaces for managing HSM instances.

Implements a REST model with the following objects:

Defined Under Namespace

Classes: Configuration

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#location_path, #single_tenant_hsm_instance_path, #single_tenant_hsm_instance_proposal_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new HsmManagement client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::Kms::V1::HsmManagement::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::Kms::V1::HsmManagement::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the HsmManagement client.

Yield Parameters:



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/google/cloud/kms/v1/hsm_management/client.rb', line 177

def initialize
  # These require statements are intentionally placed here to initialize
  # the gRPC module only when it's required.
  # See https://github.com/googleapis/toolkit/issues/446
  require "gapic/grpc"
  require "google/cloud/kms/v1/hsm_management_services_pb"

  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end
  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @operations_client = Operations.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @config.endpoint
    config.universe_domain = @config.universe_domain
  end

  @hsm_management_stub = ::Gapic::ServiceStub.new(
    ::Google::Cloud::Kms::V1::HsmManagement::Stub,
    credentials: credentials,
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    channel_args: @config.channel_args,
    interceptors: @config.interceptors,
    channel_pool_config: @config.channel_pool,
    logger: @config.logger
  )

  @hsm_management_stub.stub_logger&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end

  @location_client = Google::Cloud::Location::Locations::Client.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @hsm_management_stub.endpoint
    config.universe_domain = @hsm_management_stub.universe_domain
    config.logger = @hsm_management_stub.logger if config.respond_to? :logger=
  end

  @iam_policy_client = Google::Iam::V1::IAMPolicy::Client.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @hsm_management_stub.endpoint
    config.universe_domain = @hsm_management_stub.universe_domain
    config.logger = @hsm_management_stub.logger if config.respond_to? :logger=
  end
end

Instance Attribute Details

#iam_policy_clientGoogle::Iam::V1::IAMPolicy::Client (readonly)

Get the associated client for mix-in of the IAMPolicy.

Returns:

  • (Google::Iam::V1::IAMPolicy::Client)


270
271
272
# File 'lib/google/cloud/kms/v1/hsm_management/client.rb', line 270

def iam_policy_client
  @iam_policy_client
end

#location_clientGoogle::Cloud::Location::Locations::Client (readonly)

Get the associated client for mix-in of the Locations.

Returns:

  • (Google::Cloud::Location::Locations::Client)


263
264
265
# File 'lib/google/cloud/kms/v1/hsm_management/client.rb', line 263

def location_client
  @location_client
end

#operations_client::Google::Cloud::Kms::V1::HsmManagement::Operations (readonly)

Get the associated client for long-running operations.



256
257
258
# File 'lib/google/cloud/kms/v1/hsm_management/client.rb', line 256

def operations_client
  @operations_client
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the HsmManagement Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all HsmManagement clients
::Google::Cloud::Kms::V1::HsmManagement::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/google/cloud/kms/v1/hsm_management/client.rb', line 70

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "Kms", "V1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.rpcs.list_single_tenant_hsm_instances.timeout = 60.0
    default_config.rpcs.list_single_tenant_hsm_instances.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14, 4]
    }

    default_config.rpcs.get_single_tenant_hsm_instance.timeout = 60.0
    default_config.rpcs.get_single_tenant_hsm_instance.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14, 4]
    }

    default_config.rpcs.create_single_tenant_hsm_instance.timeout = 60.0
    default_config.rpcs.create_single_tenant_hsm_instance.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14, 4]
    }

    default_config.rpcs.create_single_tenant_hsm_instance_proposal.timeout = 60.0
    default_config.rpcs.create_single_tenant_hsm_instance_proposal.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14, 4]
    }

    default_config.rpcs.approve_single_tenant_hsm_instance_proposal.timeout = 60.0
    default_config.rpcs.approve_single_tenant_hsm_instance_proposal.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14, 4]
    }

    default_config.rpcs.execute_single_tenant_hsm_instance_proposal.timeout = 60.0
    default_config.rpcs.execute_single_tenant_hsm_instance_proposal.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14, 4]
    }

    default_config.rpcs.get_single_tenant_hsm_instance_proposal.timeout = 60.0
    default_config.rpcs.get_single_tenant_hsm_instance_proposal.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14, 4]
    }

    default_config.rpcs.list_single_tenant_hsm_instance_proposals.timeout = 60.0
    default_config.rpcs.list_single_tenant_hsm_instance_proposals.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14, 4]
    }

    default_config.rpcs.delete_single_tenant_hsm_instance_proposal.timeout = 60.0
    default_config.rpcs.delete_single_tenant_hsm_instance_proposal.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14, 4]
    }

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#approve_single_tenant_hsm_instance_proposal(request, options = nil) ⇒ ::Google::Cloud::Kms::V1::ApproveSingleTenantHsmInstanceProposalResponse #approve_single_tenant_hsm_instance_proposal(name: nil, quorum_reply: nil, required_action_quorum_reply: nil) ⇒ ::Google::Cloud::Kms::V1::ApproveSingleTenantHsmInstanceProposalResponse

Approves a SingleTenantHsmInstanceProposal for a given SingleTenantHsmInstance. The proposal must be in the PENDING state.

Examples:

Basic example

require "google/cloud/kms/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Kms::V1::HsmManagement::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Kms::V1::ApproveSingleTenantHsmInstanceProposalRequest.new

# Call the approve_single_tenant_hsm_instance_proposal method.
result = client.approve_single_tenant_hsm_instance_proposal request

# The returned object is of type Google::Cloud::Kms::V1::ApproveSingleTenantHsmInstanceProposalResponse.
p result

Overloads:

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
# File 'lib/google/cloud/kms/v1/hsm_management/client.rb', line 773

def approve_single_tenant_hsm_instance_proposal request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Kms::V1::ApproveSingleTenantHsmInstanceProposalRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.approve_single_tenant_hsm_instance_proposal..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Kms::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.approve_single_tenant_hsm_instance_proposal.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.approve_single_tenant_hsm_instance_proposal.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @hsm_management_stub.call_rpc :approve_single_tenant_hsm_instance_proposal, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#configure {|config| ... } ⇒ Client::Configuration

Configure the HsmManagement Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



147
148
149
150
# File 'lib/google/cloud/kms/v1/hsm_management/client.rb', line 147

def configure
  yield @config if block_given?
  @config
end

#create_single_tenant_hsm_instance(request, options = nil) ⇒ ::Gapic::Operation #create_single_tenant_hsm_instance(parent: nil, single_tenant_hsm_instance_id: nil, single_tenant_hsm_instance: nil) ⇒ ::Gapic::Operation

Creates a new SingleTenantHsmInstance in a given Project and Location. User must create a RegisterTwoFactorAuthKeys proposal with this single-tenant HSM instance to finish setup of the instance.

Examples:

Basic example

require "google/cloud/kms/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Kms::V1::HsmManagement::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Kms::V1::CreateSingleTenantHsmInstanceRequest.new

# Call the create_single_tenant_hsm_instance method.
result = client.create_single_tenant_hsm_instance request

# The returned object is of type Gapic::Operation. You can use it to
# check the status of an operation, cancel it, or wait for results.
# Here is how to wait for a response.
result.wait_until_done! timeout: 60
if result.response?
  p result.response
else
  puts "No response received."
end

Overloads:

  • #create_single_tenant_hsm_instance(request, options = nil) ⇒ ::Gapic::Operation

    Pass arguments to create_single_tenant_hsm_instance via a request object, either of type CreateSingleTenantHsmInstanceRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Kms::V1::CreateSingleTenantHsmInstanceRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #create_single_tenant_hsm_instance(parent: nil, single_tenant_hsm_instance_id: nil, single_tenant_hsm_instance: nil) ⇒ ::Gapic::Operation

    Pass arguments to create_single_tenant_hsm_instance via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The resource name of the location associated with the SingleTenantHsmInstance, in the format projects/*/locations/*.

    • single_tenant_hsm_instance_id (::String) (defaults to: nil)

      Optional. It must be unique within a location and match the regular expression [a-zA-Z0-9_-]{1,63}.

    • single_tenant_hsm_instance (::Google::Cloud::Kms::V1::SingleTenantHsmInstance, ::Hash) (defaults to: nil)

      Required. An SingleTenantHsmInstance with initial field values.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

  • response (::Gapic::Operation)
  • operation (::GRPC::ActiveCall::Operation)

Returns:

  • (::Gapic::Operation)

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
# File 'lib/google/cloud/kms/v1/hsm_management/client.rb', line 558

def create_single_tenant_hsm_instance request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Kms::V1::CreateSingleTenantHsmInstanceRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_single_tenant_hsm_instance..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Kms::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.create_single_tenant_hsm_instance.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_single_tenant_hsm_instance.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @hsm_management_stub.call_rpc :create_single_tenant_hsm_instance, request, options: options do |response, operation|
    response = ::Gapic::Operation.new response, @operations_client, options: options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#create_single_tenant_hsm_instance_proposal(request, options = nil) ⇒ ::Gapic::Operation #create_single_tenant_hsm_instance_proposal(parent: nil, single_tenant_hsm_instance_proposal_id: nil, single_tenant_hsm_instance_proposal: nil) ⇒ ::Gapic::Operation

Examples:

Basic example

require "google/cloud/kms/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Kms::V1::HsmManagement::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Kms::V1::CreateSingleTenantHsmInstanceProposalRequest.new

# Call the create_single_tenant_hsm_instance_proposal method.
result = client.create_single_tenant_hsm_instance_proposal request

# The returned object is of type Gapic::Operation. You can use it to
# check the status of an operation, cancel it, or wait for results.
# Here is how to wait for a response.
result.wait_until_done! timeout: 60
if result.response?
  p result.response
else
  puts "No response received."
end

Overloads:

  • #create_single_tenant_hsm_instance_proposal(request, options = nil) ⇒ ::Gapic::Operation

    Pass arguments to create_single_tenant_hsm_instance_proposal via a request object, either of type CreateSingleTenantHsmInstanceProposalRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Kms::V1::CreateSingleTenantHsmInstanceProposalRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #create_single_tenant_hsm_instance_proposal(parent: nil, single_tenant_hsm_instance_proposal_id: nil, single_tenant_hsm_instance_proposal: nil) ⇒ ::Gapic::Operation

    Pass arguments to create_single_tenant_hsm_instance_proposal via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

  • response (::Gapic::Operation)
  • operation (::GRPC::ActiveCall::Operation)

Returns:

  • (::Gapic::Operation)

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
# File 'lib/google/cloud/kms/v1/hsm_management/client.rb', line 665

def create_single_tenant_hsm_instance_proposal request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Kms::V1::CreateSingleTenantHsmInstanceProposalRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_single_tenant_hsm_instance_proposal..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Kms::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.create_single_tenant_hsm_instance_proposal.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_single_tenant_hsm_instance_proposal.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @hsm_management_stub.call_rpc :create_single_tenant_hsm_instance_proposal, request, options: options do |response, operation|
    response = ::Gapic::Operation.new response, @operations_client, options: options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#delete_single_tenant_hsm_instance_proposal(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_single_tenant_hsm_instance_proposal(name: nil) ⇒ ::Google::Protobuf::Empty

Examples:

Basic example

require "google/cloud/kms/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Kms::V1::HsmManagement::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Kms::V1::DeleteSingleTenantHsmInstanceProposalRequest.new

# Call the delete_single_tenant_hsm_instance_proposal method.
result = client.delete_single_tenant_hsm_instance_proposal request

# The returned object is of type Google::Protobuf::Empty.
p result

Overloads:

  • #delete_single_tenant_hsm_instance_proposal(request, options = nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_single_tenant_hsm_instance_proposal via a request object, either of type DeleteSingleTenantHsmInstanceProposalRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Kms::V1::DeleteSingleTenantHsmInstanceProposalRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #delete_single_tenant_hsm_instance_proposal(name: nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_single_tenant_hsm_instance_proposal via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
# File 'lib/google/cloud/kms/v1/hsm_management/client.rb', line 1177

def delete_single_tenant_hsm_instance_proposal request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Kms::V1::DeleteSingleTenantHsmInstanceProposalRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.delete_single_tenant_hsm_instance_proposal..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Kms::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.delete_single_tenant_hsm_instance_proposal.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.delete_single_tenant_hsm_instance_proposal.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @hsm_management_stub.call_rpc :delete_single_tenant_hsm_instance_proposal, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#execute_single_tenant_hsm_instance_proposal(request, options = nil) ⇒ ::Gapic::Operation #execute_single_tenant_hsm_instance_proposal(name: nil) ⇒ ::Gapic::Operation

Executes a SingleTenantHsmInstanceProposal for a given SingleTenantHsmInstance. The proposal must be in the APPROVED state.

Examples:

Basic example

require "google/cloud/kms/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Kms::V1::HsmManagement::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Kms::V1::ExecuteSingleTenantHsmInstanceProposalRequest.new

# Call the execute_single_tenant_hsm_instance_proposal method.
result = client.execute_single_tenant_hsm_instance_proposal request

# The returned object is of type Gapic::Operation. You can use it to
# check the status of an operation, cancel it, or wait for results.
# Here is how to wait for a response.
result.wait_until_done! timeout: 60
if result.response?
  p result.response
else
  puts "No response received."
end

Overloads:

  • #execute_single_tenant_hsm_instance_proposal(request, options = nil) ⇒ ::Gapic::Operation

    Pass arguments to execute_single_tenant_hsm_instance_proposal via a request object, either of type ExecuteSingleTenantHsmInstanceProposalRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Kms::V1::ExecuteSingleTenantHsmInstanceProposalRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #execute_single_tenant_hsm_instance_proposal(name: nil) ⇒ ::Gapic::Operation

    Pass arguments to execute_single_tenant_hsm_instance_proposal via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

  • response (::Gapic::Operation)
  • operation (::GRPC::ActiveCall::Operation)

Returns:

  • (::Gapic::Operation)

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
# File 'lib/google/cloud/kms/v1/hsm_management/client.rb', line 874

def execute_single_tenant_hsm_instance_proposal request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Kms::V1::ExecuteSingleTenantHsmInstanceProposalRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.execute_single_tenant_hsm_instance_proposal..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Kms::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.execute_single_tenant_hsm_instance_proposal.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.execute_single_tenant_hsm_instance_proposal.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @hsm_management_stub.call_rpc :execute_single_tenant_hsm_instance_proposal, request, options: options do |response, operation|
    response = ::Gapic::Operation.new response, @operations_client, options: options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_single_tenant_hsm_instance(request, options = nil) ⇒ ::Google::Cloud::Kms::V1::SingleTenantHsmInstance #get_single_tenant_hsm_instance(name: nil) ⇒ ::Google::Cloud::Kms::V1::SingleTenantHsmInstance

Returns metadata for a given SingleTenantHsmInstance.

Examples:

Basic example

require "google/cloud/kms/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Kms::V1::HsmManagement::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Kms::V1::GetSingleTenantHsmInstanceRequest.new

# Call the get_single_tenant_hsm_instance method.
result = client.get_single_tenant_hsm_instance request

# The returned object is of type Google::Cloud::Kms::V1::SingleTenantHsmInstance.
p result

Overloads:

  • #get_single_tenant_hsm_instance(request, options = nil) ⇒ ::Google::Cloud::Kms::V1::SingleTenantHsmInstance

    Pass arguments to get_single_tenant_hsm_instance via a request object, either of type GetSingleTenantHsmInstanceRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Kms::V1::GetSingleTenantHsmInstanceRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #get_single_tenant_hsm_instance(name: nil) ⇒ ::Google::Cloud::Kms::V1::SingleTenantHsmInstance

    Pass arguments to get_single_tenant_hsm_instance via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'lib/google/cloud/kms/v1/hsm_management/client.rb', line 453

def get_single_tenant_hsm_instance request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Kms::V1::GetSingleTenantHsmInstanceRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_single_tenant_hsm_instance..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Kms::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.get_single_tenant_hsm_instance.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_single_tenant_hsm_instance.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @hsm_management_stub.call_rpc :get_single_tenant_hsm_instance, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_single_tenant_hsm_instance_proposal(request, options = nil) ⇒ ::Google::Cloud::Kms::V1::SingleTenantHsmInstanceProposal #get_single_tenant_hsm_instance_proposal(name: nil) ⇒ ::Google::Cloud::Kms::V1::SingleTenantHsmInstanceProposal

Returns metadata for a given SingleTenantHsmInstanceProposal.

Examples:

Basic example

require "google/cloud/kms/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Kms::V1::HsmManagement::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Kms::V1::GetSingleTenantHsmInstanceProposalRequest.new

# Call the get_single_tenant_hsm_instance_proposal method.
result = client.get_single_tenant_hsm_instance_proposal request

# The returned object is of type Google::Cloud::Kms::V1::SingleTenantHsmInstanceProposal.
p result

Overloads:

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
# File 'lib/google/cloud/kms/v1/hsm_management/client.rb', line 965

def get_single_tenant_hsm_instance_proposal request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Kms::V1::GetSingleTenantHsmInstanceProposalRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_single_tenant_hsm_instance_proposal..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Kms::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.get_single_tenant_hsm_instance_proposal.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_single_tenant_hsm_instance_proposal.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @hsm_management_stub.call_rpc :get_single_tenant_hsm_instance_proposal, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_single_tenant_hsm_instance_proposals(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Kms::V1::SingleTenantHsmInstanceProposal> #list_single_tenant_hsm_instance_proposals(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil, show_deleted: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Kms::V1::SingleTenantHsmInstanceProposal>

Examples:

Basic example

require "google/cloud/kms/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Kms::V1::HsmManagement::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Kms::V1::ListSingleTenantHsmInstanceProposalsRequest.new

# Call the list_single_tenant_hsm_instance_proposals method.
result = client.list_single_tenant_hsm_instance_proposals request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::Kms::V1::SingleTenantHsmInstanceProposal.
  p item
end

Overloads:

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
# File 'lib/google/cloud/kms/v1/hsm_management/client.rb', line 1086

def list_single_tenant_hsm_instance_proposals request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Kms::V1::ListSingleTenantHsmInstanceProposalsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_single_tenant_hsm_instance_proposals..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Kms::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.list_single_tenant_hsm_instance_proposals.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_single_tenant_hsm_instance_proposals.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @hsm_management_stub.call_rpc :list_single_tenant_hsm_instance_proposals, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @hsm_management_stub, :list_single_tenant_hsm_instance_proposals, request, response, operation, options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_single_tenant_hsm_instances(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Kms::V1::SingleTenantHsmInstance> #list_single_tenant_hsm_instances(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil, show_deleted: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Kms::V1::SingleTenantHsmInstance>

Examples:

Basic example

require "google/cloud/kms/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Kms::V1::HsmManagement::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Kms::V1::ListSingleTenantHsmInstancesRequest.new

# Call the list_single_tenant_hsm_instances method.
result = client.list_single_tenant_hsm_instances request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::Kms::V1::SingleTenantHsmInstance.
  p item
end

Overloads:

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
# File 'lib/google/cloud/kms/v1/hsm_management/client.rb', line 363

def list_single_tenant_hsm_instances request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Kms::V1::ListSingleTenantHsmInstancesRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_single_tenant_hsm_instances..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Kms::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.list_single_tenant_hsm_instances.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_single_tenant_hsm_instances.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @hsm_management_stub.call_rpc :list_single_tenant_hsm_instances, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @hsm_management_stub, :list_single_tenant_hsm_instances, request, response, operation, options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


277
278
279
# File 'lib/google/cloud/kms/v1/hsm_management/client.rb', line 277

def logger
  @hsm_management_stub.logger
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


157
158
159
# File 'lib/google/cloud/kms/v1/hsm_management/client.rb', line 157

def universe_domain
  @hsm_management_stub.universe_domain
end