Class: Google::Cloud::Kms::V1::ImportCryptoKeyVersionRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Kms::V1::ImportCryptoKeyVersionRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/kms/v1/service.rb
Overview
Request message for KeyManagementService.ImportCryptoKeyVersion.
Instance Attribute Summary collapse
-
#algorithm ⇒ ::Google::Cloud::Kms::V1::CryptoKeyVersion::CryptoKeyVersionAlgorithm
Required.
-
#crypto_key_version ⇒ ::String
Optional.
-
#import_job ⇒ ::String
Required.
-
#parent ⇒ ::String
Required.
-
#rsa_aes_wrapped_key ⇒ ::String
Optional.
-
#trusted_wrapping_enabled ⇒ ::Boolean
Optional.
-
#wrapped_key ⇒ ::String
Optional.
Instance Attribute Details
#algorithm ⇒ ::Google::Cloud::Kms::V1::CryptoKeyVersion::CryptoKeyVersionAlgorithm
Returns Required. The algorithm of the key being imported. This does not need to match the version_template of the CryptoKey this version imports into.
599 600 601 602 |
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 599 class ImportCryptoKeyVersionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#crypto_key_version ⇒ ::String
Returns Optional. The optional name of an existing CryptoKeyVersion to target for an import operation. If this field is not present, a new CryptoKeyVersion containing the supplied key material is created.
If this field is present, the supplied key material is imported into the existing CryptoKeyVersion. To import into an existing CryptoKeyVersion, the CryptoKeyVersion must be a child of ImportCryptoKeyVersionRequest.parent, have been previously created via ImportCryptoKeyVersion, and be in DESTROYED or IMPORT_FAILED state. The key material and algorithm must match the previous CryptoKeyVersion exactly if the CryptoKeyVersion has ever contained key material.
599 600 601 602 |
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 599 class ImportCryptoKeyVersionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#import_job ⇒ ::String
599 600 601 602 |
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 599 class ImportCryptoKeyVersionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The name of the CryptoKey to be imported into.
The create permission is only required on this key when creating a new CryptoKeyVersion.
599 600 601 602 |
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 599 class ImportCryptoKeyVersionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#rsa_aes_wrapped_key ⇒ ::String
Returns Optional. This field has the same meaning as wrapped_key. Prefer to use that field in new work. Either that field or this field (but not both) must be specified.
599 600 601 602 |
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 599 class ImportCryptoKeyVersionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#trusted_wrapping_enabled ⇒ ::Boolean
Returns Optional. Whether trusted wrapping will be enabled on the imported [CryptoKeyVersion]. This field is only supported for keys with CryptoKeyVersionTemplate.protection_level HSM_SINGLE_TENANT. This field is supported for all CryptoKeyPurposes besides ENCRYPT_DECRYPT.
599 600 601 602 |
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 599 class ImportCryptoKeyVersionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#wrapped_key ⇒ ::String
Returns Optional. The wrapped key material to import.
Before wrapping, key material must be formatted. If importing symmetric key material, the expected key material format is plain bytes. If importing asymmetric key material, the expected key material format is PKCS#8-encoded DER (the PrivateKeyInfo structure from RFC 5208).
When wrapping with import methods (RSA_OAEP_3072_SHA1_AES_256 or RSA_OAEP_4096_SHA1_AES_256 or RSA_OAEP_3072_SHA256_AES_256 or RSA_OAEP_4096_SHA256_AES_256),
this field must contain the concatenation of:
- An ephemeral AES-256 wrapping key wrapped with the public_key using RSAES-OAEP with SHA-1/SHA-256, MGF1 with SHA-1/SHA-256, and an empty label.
- The formatted key to be imported, wrapped with the ephemeral AES-256 key using AES-KWP (RFC 5649).
This format is the same as the format produced by PKCS#11 mechanism CKM_RSA_AES_KEY_WRAP.
When wrapping with import methods (RSA_OAEP_3072_SHA256 or RSA_OAEP_4096_SHA256),
this field must contain the formatted key to be imported, wrapped with the public_key using RSAES-OAEP with SHA-256, MGF1 with SHA-256, and an empty label.
599 600 601 602 |
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 599 class ImportCryptoKeyVersionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |