Class: Google::Cloud::Kms::V1::ImportJob::WrappingPublicKey
- Inherits:
-
Object
- Object
- Google::Cloud::Kms::V1::ImportJob::WrappingPublicKey
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/kms/v1/resources.rb
Overview
The public key component of the wrapping key. For details of the type of key this public key corresponds to, see the ImportMethod.
Instance Attribute Summary collapse
-
#data ⇒ ::String
readonly
Output only.
-
#pem ⇒ ::String
The public key, encoded in PEM format.
Instance Attribute Details
#data ⇒ ::String (readonly)
Returns Output only. Contains the public key, formatted according to the PublicKey.PublicKeyFormat specified in the KeyManagementService.GetImportJob request.
949 950 951 952 |
# File 'proto_docs/google/cloud/kms/v1/resources.rb', line 949 class WrappingPublicKey include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#pem ⇒ ::String
Returns The public key, encoded in PEM format. For more information, see the RFC 7468 sections for General Considerations and Textual Encoding of Subject Public Key Info. This field gets populated by default for RSA-based import methods, if no public_key_format is specified in the request. If you want to retrieve the wrapping key of an ImportJob in some other format, use KeyManagementService.GetImportJob and set the public_key_format to the desired public key format.
949 950 951 952 |
# File 'proto_docs/google/cloud/kms/v1/resources.rb', line 949 class WrappingPublicKey include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |