Class: Google::Cloud::Kms::V1::ListSingleTenantHsmInstanceProposalsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Kms::V1::ListSingleTenantHsmInstanceProposalsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/kms/v1/hsm_management.rb
Overview
Request message for HsmManagement.ListSingleTenantHsmInstanceProposals.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#order_by ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
-
#show_deleted ⇒ ::Boolean
Optional.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. Only include resources that match the filter in the response. For more information, see Sorting and filtering list results.
838 839 840 841 |
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 838 class ListSingleTenantHsmInstanceProposalsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#order_by ⇒ ::String
Returns Optional. Specify how the results should be sorted. If not specified, the results will be sorted in the default order. For more information, see Sorting and filtering list results.
838 839 840 841 |
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 838 class ListSingleTenantHsmInstanceProposalsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. Optional limit on the number of SingleTenantHsmInstanceProposals to include in the response. Further SingleTenantHsmInstanceProposals can subsequently be obtained by including the ListSingleTenantHsmInstanceProposalsResponse.next_page_token in a subsequent request. If unspecified, the server will pick an appropriate default.
838 839 840 841 |
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 838 class ListSingleTenantHsmInstanceProposalsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. Optional pagination token, returned earlier via ListSingleTenantHsmInstanceProposalsResponse.next_page_token.
838 839 840 841 |
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 838 class ListSingleTenantHsmInstanceProposalsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The resource name of the single tenant HSM instance associated
with the
SingleTenantHsmInstanceProposals
to list, in the format projects/*/locations/*/singleTenantHsmInstances/*.
838 839 840 841 |
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 838 class ListSingleTenantHsmInstanceProposalsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#show_deleted ⇒ ::Boolean
Returns Optional. If set to true, HsmManagement.ListSingleTenantHsmInstanceProposals will also return SingleTenantHsmInstanceProposals in DELETED state.
838 839 840 841 |
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 838 class ListSingleTenantHsmInstanceProposalsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |