Module: Google::Cloud::Kms::V1::PublicKey::PublicKeyFormat
- Defined in:
- proto_docs/google/cloud/kms/v1/resources.rb
Overview
The supported PublicKey formats.
Constant Summary collapse
- PUBLIC_KEY_FORMAT_UNSPECIFIED =
If the public_key_format field is not specified:
- For PQC algorithms, an error will be returned.
- For non-PQC algorithms, the default format is PEM, and the field pem will be populated.
Otherwise, the public key will be exported through the public_key field in the requested format.
0- PEM =
The returned public key will be encoded in PEM format. See the RFC7468 sections for General Considerations and Textual Encoding of Subject Public Key Info for more information.
1- DER =
The returned public key will be encoded in DER format (the PrivateKeyInfo structure from RFC 5208).
2- NIST_PQC =
This is supported only for PQC algorithms. The key material is returned in the format defined by NIST PQC standards (FIPS 203, FIPS 204, and FIPS 205).
3- XWING_RAW_BYTES =
The returned public key is in raw bytes format defined in its standard https://datatracker.ietf.org/doc/draft-connolly-cfrg-xwing-kem.
4