Module: Google::Cloud::Kms::V1::SingleTenantHsmInstance::State

Defined in:
proto_docs/google/cloud/kms/v1/hsm_management.rb

Overview

The set of states of a SingleTenantHsmInstance.

Constant Summary collapse

STATE_UNSPECIFIED =

Not specified.

0
CREATING =

The SingleTenantHsmInstance is being created.

1
PENDING_TWO_FACTOR_AUTH_REGISTRATION =

The SingleTenantHsmInstance is waiting for 2FA keys to be registered. This can be done by calling CreateSingleTenantHsmInstanceProposal with the [RegisterTwoFactorAuthKeys][] operation.

2
ACTIVE =

The SingleTenantHsmInstance is ready to use. A SingleTenantHsmInstance must be in the ACTIVE state for all CryptoKeys created within the SingleTenantHsmInstance to be usable.

3
DISABLING =

The SingleTenantHsmInstance is being disabled.

4
DISABLED =

The SingleTenantHsmInstance is disabled.

5
DELETING =

The SingleTenantHsmInstance is being deleted. Requests to the instance will be rejected in this state.

6
DELETED =

The SingleTenantHsmInstance has been deleted.

7
FAILED =

The SingleTenantHsmInstance has failed and can not be recovered or used.

8