Class: Google::Cloud::Kms::V1::SingleTenantHsmInstanceProposal::AddQuorumMember

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/kms/v1/hsm_management.rb

Overview

Add a quorum member to the SingleTenantHsmInstance. This will increase the total_approver_count by 1. The SingleTenantHsmInstance must be in the ACTIVE state to perform this operation.

Instance Attribute Summary collapse

Instance Attribute Details

#two_factor_public_key_pem::String

Returns Required. The public key associated with the 2FA key for the new quorum member to add. Public keys must be associated with RSA 2048 keys.

Returns:

  • (::String)

    Required. The public key associated with the 2FA key for the new quorum member to add. Public keys must be associated with RSA 2048 keys.



437
438
439
440
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 437

class AddQuorumMember
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end