Class: Google::Cloud::Kms::V1::SingleTenantHsmInstanceProposal::QuorumParameters
- Inherits:
-
Object
- Object
- Google::Cloud::Kms::V1::SingleTenantHsmInstanceProposal::QuorumParameters
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/kms/v1/hsm_management.rb
Overview
Parameters of quorum approval for the SingleTenantHsmInstanceProposal.
Instance Attribute Summary collapse
-
#approved_two_factor_public_key_pems ⇒ ::Array<::String>
readonly
Output only.
-
#challenges ⇒ ::Array<::Google::Cloud::Kms::V1::Challenge>
readonly
Output only.
-
#required_approver_count ⇒ ::Integer
readonly
Output only.
Instance Attribute Details
#approved_two_factor_public_key_pems ⇒ ::Array<::String> (readonly)
Returns Output only. The public keys associated with the 2FA keys that have already approved the SingleTenantHsmInstanceProposal by signing the challenge.
330 331 332 333 |
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 330 class QuorumParameters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#challenges ⇒ ::Array<::Google::Cloud::Kms::V1::Challenge> (readonly)
Returns Output only. The challenges to be signed by 2FA keys for quorum auth. M of N of these challenges are required to be signed to approve the operation.
330 331 332 333 |
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 330 class QuorumParameters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#required_approver_count ⇒ ::Integer (readonly)
Returns Output only. The required numbers of approvers. This is the M value used for M of N quorum auth. It is less than the number of public keys.
330 331 332 333 |
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 330 class QuorumParameters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |