Class: Google::Cloud::Kms::V1::SingleTenantHsmInstanceProposal::UpgradeKeyTrust

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/kms/v1/hsm_management.rb

Overview

Promotes a key with the AES_WRAPPING purpose to a trusted wrapping key. The key must be in the [ACTIVE][CryptoKeyVersion.CryptoKeyVersionState.ACTIVE] state to perform this operation.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The name of the CryptoKeyVersion to promote.

Returns:



496
497
498
499
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 496

class UpgradeKeyTrust
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#two_factor_public_key_pem::String

Returns Required. The public key associated with the 2FA key that will sign the login nonce for this operation.

Returns:

  • (::String)

    Required. The public key associated with the 2FA key that will sign the login nonce for this operation.



496
497
498
499
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 496

class UpgradeKeyTrust
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end