Class: Google::Cloud::Kms::V1::AutokeyConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Kms::V1::AutokeyConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/kms/v1/autokey_admin.rb
Overview
Cloud KMS Autokey configuration for a folder.
Defined Under Namespace
Modules: KeyProjectResolutionMode, State
Instance Attribute Summary collapse
-
#etag ⇒ ::String
Optional.
-
#key_project ⇒ ::String
Optional.
-
#key_project_resolution_mode ⇒ ::Google::Cloud::Kms::V1::AutokeyConfig::KeyProjectResolutionMode
Optional.
-
#name ⇒ ::String
Identifier.
-
#state ⇒ ::Google::Cloud::Kms::V1::AutokeyConfig::State
readonly
Output only.
Instance Attribute Details
#etag ⇒ ::String
Returns Optional. A checksum computed by the server based on the value of other fields. This may be sent on update requests to ensure that the client has an up-to-date value before proceeding. The request will be rejected with an ABORTED error on a mismatched etag.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'proto_docs/google/cloud/kms/v1/autokey_admin.rb', line 85 class AutokeyConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The states AutokeyConfig can be in. module State # The state of the AutokeyConfig is unspecified. STATE_UNSPECIFIED = 0 # The AutokeyConfig is currently active. ACTIVE = 1 # A previously configured key project has been deleted and the current # AutokeyConfig is unusable. KEY_PROJECT_DELETED = 2 # The AutokeyConfig is not yet initialized or has been reset to its default # uninitialized state. UNINITIALIZED = 3 # The service account lacks the necessary permissions in the key project to # configure Autokey. KEY_PROJECT_PERMISSION_DENIED = 4 end # Defines the resolution mode enum for the key project. # The # {::Google::Cloud::Kms::V1::AutokeyConfig::KeyProjectResolutionMode KeyProjectResolutionMode} # determines the mechanism by which # {::Google::Cloud::Kms::V1::AutokeyConfig AutokeyConfig} identifies a # {::Google::Cloud::Kms::V1::AutokeyConfig#key_project key_project} at its # specific configuration node. This parameter also determines if Autokey can # be used within this project or folder. module KeyProjectResolutionMode # Default value. KeyProjectResolutionMode when not specified will act as # `DEDICATED_KEY_PROJECT`. KEY_PROJECT_RESOLUTION_MODE_UNSPECIFIED = 0 # Keys are created in a dedicated project specified by `key_project`. DEDICATED_KEY_PROJECT = 1 # Keys are created in the same project as the resource requesting the key. # The `key_project` must not be set when this mode is used. RESOURCE_PROJECT = 2 # Disables the AutokeyConfig. When this mode is set, any AutokeyConfig # from higher levels in the resource hierarchy are ignored for this # resource and its descendants. This setting can be overridden # by a more specific configuration at a lower level. For example, # if Autokey is disabled on a folder, it can be re-enabled on a sub-folder # or project within that folder by setting a different mode (e.g., # DEDICATED_KEY_PROJECT or RESOURCE_PROJECT). DISABLED = 3 end end |
#key_project ⇒ ::String
Returns Optional. Name of the key project, e.g. projects/{PROJECT_ID} or
projects/{PROJECT_NUMBER}, where Cloud KMS Autokey will provision a new
CryptoKey when a
KeyHandle is created. On
UpdateAutokeyConfig,
the caller will require cloudkms.cryptoKeys.setIamPolicy permission on
this key project. Once configured, for Cloud KMS Autokey to function
properly, this key project must have the Cloud KMS API activated and the
Cloud KMS Service Agent for this key project must be granted the
cloudkms.admin role (or pertinent permissions). A request with an empty
key project field will clear the configuration.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'proto_docs/google/cloud/kms/v1/autokey_admin.rb', line 85 class AutokeyConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The states AutokeyConfig can be in. module State # The state of the AutokeyConfig is unspecified. STATE_UNSPECIFIED = 0 # The AutokeyConfig is currently active. ACTIVE = 1 # A previously configured key project has been deleted and the current # AutokeyConfig is unusable. KEY_PROJECT_DELETED = 2 # The AutokeyConfig is not yet initialized or has been reset to its default # uninitialized state. UNINITIALIZED = 3 # The service account lacks the necessary permissions in the key project to # configure Autokey. KEY_PROJECT_PERMISSION_DENIED = 4 end # Defines the resolution mode enum for the key project. # The # {::Google::Cloud::Kms::V1::AutokeyConfig::KeyProjectResolutionMode KeyProjectResolutionMode} # determines the mechanism by which # {::Google::Cloud::Kms::V1::AutokeyConfig AutokeyConfig} identifies a # {::Google::Cloud::Kms::V1::AutokeyConfig#key_project key_project} at its # specific configuration node. This parameter also determines if Autokey can # be used within this project or folder. module KeyProjectResolutionMode # Default value. KeyProjectResolutionMode when not specified will act as # `DEDICATED_KEY_PROJECT`. KEY_PROJECT_RESOLUTION_MODE_UNSPECIFIED = 0 # Keys are created in a dedicated project specified by `key_project`. DEDICATED_KEY_PROJECT = 1 # Keys are created in the same project as the resource requesting the key. # The `key_project` must not be set when this mode is used. RESOURCE_PROJECT = 2 # Disables the AutokeyConfig. When this mode is set, any AutokeyConfig # from higher levels in the resource hierarchy are ignored for this # resource and its descendants. This setting can be overridden # by a more specific configuration at a lower level. For example, # if Autokey is disabled on a folder, it can be re-enabled on a sub-folder # or project within that folder by setting a different mode (e.g., # DEDICATED_KEY_PROJECT or RESOURCE_PROJECT). DISABLED = 3 end end |
#key_project_resolution_mode ⇒ ::Google::Cloud::Kms::V1::AutokeyConfig::KeyProjectResolutionMode
Returns Optional. KeyProjectResolutionMode for the AutokeyConfig.
Valid values are DEDICATED_KEY_PROJECT, RESOURCE_PROJECT, or
DISABLED.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'proto_docs/google/cloud/kms/v1/autokey_admin.rb', line 85 class AutokeyConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The states AutokeyConfig can be in. module State # The state of the AutokeyConfig is unspecified. STATE_UNSPECIFIED = 0 # The AutokeyConfig is currently active. ACTIVE = 1 # A previously configured key project has been deleted and the current # AutokeyConfig is unusable. KEY_PROJECT_DELETED = 2 # The AutokeyConfig is not yet initialized or has been reset to its default # uninitialized state. UNINITIALIZED = 3 # The service account lacks the necessary permissions in the key project to # configure Autokey. KEY_PROJECT_PERMISSION_DENIED = 4 end # Defines the resolution mode enum for the key project. # The # {::Google::Cloud::Kms::V1::AutokeyConfig::KeyProjectResolutionMode KeyProjectResolutionMode} # determines the mechanism by which # {::Google::Cloud::Kms::V1::AutokeyConfig AutokeyConfig} identifies a # {::Google::Cloud::Kms::V1::AutokeyConfig#key_project key_project} at its # specific configuration node. This parameter also determines if Autokey can # be used within this project or folder. module KeyProjectResolutionMode # Default value. KeyProjectResolutionMode when not specified will act as # `DEDICATED_KEY_PROJECT`. KEY_PROJECT_RESOLUTION_MODE_UNSPECIFIED = 0 # Keys are created in a dedicated project specified by `key_project`. DEDICATED_KEY_PROJECT = 1 # Keys are created in the same project as the resource requesting the key. # The `key_project` must not be set when this mode is used. RESOURCE_PROJECT = 2 # Disables the AutokeyConfig. When this mode is set, any AutokeyConfig # from higher levels in the resource hierarchy are ignored for this # resource and its descendants. This setting can be overridden # by a more specific configuration at a lower level. For example, # if Autokey is disabled on a folder, it can be re-enabled on a sub-folder # or project within that folder by setting a different mode (e.g., # DEDICATED_KEY_PROJECT or RESOURCE_PROJECT). DISABLED = 3 end end |
#name ⇒ ::String
Returns Identifier. Name of the AutokeyConfig
resource, e.g. folders/{FOLDER_NUMBER}/autokeyConfig or
projects/{PROJECT_NUMBER}/autokeyConfig.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'proto_docs/google/cloud/kms/v1/autokey_admin.rb', line 85 class AutokeyConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The states AutokeyConfig can be in. module State # The state of the AutokeyConfig is unspecified. STATE_UNSPECIFIED = 0 # The AutokeyConfig is currently active. ACTIVE = 1 # A previously configured key project has been deleted and the current # AutokeyConfig is unusable. KEY_PROJECT_DELETED = 2 # The AutokeyConfig is not yet initialized or has been reset to its default # uninitialized state. UNINITIALIZED = 3 # The service account lacks the necessary permissions in the key project to # configure Autokey. KEY_PROJECT_PERMISSION_DENIED = 4 end # Defines the resolution mode enum for the key project. # The # {::Google::Cloud::Kms::V1::AutokeyConfig::KeyProjectResolutionMode KeyProjectResolutionMode} # determines the mechanism by which # {::Google::Cloud::Kms::V1::AutokeyConfig AutokeyConfig} identifies a # {::Google::Cloud::Kms::V1::AutokeyConfig#key_project key_project} at its # specific configuration node. This parameter also determines if Autokey can # be used within this project or folder. module KeyProjectResolutionMode # Default value. KeyProjectResolutionMode when not specified will act as # `DEDICATED_KEY_PROJECT`. KEY_PROJECT_RESOLUTION_MODE_UNSPECIFIED = 0 # Keys are created in a dedicated project specified by `key_project`. DEDICATED_KEY_PROJECT = 1 # Keys are created in the same project as the resource requesting the key. # The `key_project` must not be set when this mode is used. RESOURCE_PROJECT = 2 # Disables the AutokeyConfig. When this mode is set, any AutokeyConfig # from higher levels in the resource hierarchy are ignored for this # resource and its descendants. This setting can be overridden # by a more specific configuration at a lower level. For example, # if Autokey is disabled on a folder, it can be re-enabled on a sub-folder # or project within that folder by setting a different mode (e.g., # DEDICATED_KEY_PROJECT or RESOURCE_PROJECT). DISABLED = 3 end end |
#state ⇒ ::Google::Cloud::Kms::V1::AutokeyConfig::State (readonly)
Returns Output only. The state for the AutokeyConfig.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'proto_docs/google/cloud/kms/v1/autokey_admin.rb', line 85 class AutokeyConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The states AutokeyConfig can be in. module State # The state of the AutokeyConfig is unspecified. STATE_UNSPECIFIED = 0 # The AutokeyConfig is currently active. ACTIVE = 1 # A previously configured key project has been deleted and the current # AutokeyConfig is unusable. KEY_PROJECT_DELETED = 2 # The AutokeyConfig is not yet initialized or has been reset to its default # uninitialized state. UNINITIALIZED = 3 # The service account lacks the necessary permissions in the key project to # configure Autokey. KEY_PROJECT_PERMISSION_DENIED = 4 end # Defines the resolution mode enum for the key project. # The # {::Google::Cloud::Kms::V1::AutokeyConfig::KeyProjectResolutionMode KeyProjectResolutionMode} # determines the mechanism by which # {::Google::Cloud::Kms::V1::AutokeyConfig AutokeyConfig} identifies a # {::Google::Cloud::Kms::V1::AutokeyConfig#key_project key_project} at its # specific configuration node. This parameter also determines if Autokey can # be used within this project or folder. module KeyProjectResolutionMode # Default value. KeyProjectResolutionMode when not specified will act as # `DEDICATED_KEY_PROJECT`. KEY_PROJECT_RESOLUTION_MODE_UNSPECIFIED = 0 # Keys are created in a dedicated project specified by `key_project`. DEDICATED_KEY_PROJECT = 1 # Keys are created in the same project as the resource requesting the key. # The `key_project` must not be set when this mode is used. RESOURCE_PROJECT = 2 # Disables the AutokeyConfig. When this mode is set, any AutokeyConfig # from higher levels in the resource hierarchy are ignored for this # resource and its descendants. This setting can be overridden # by a more specific configuration at a lower level. For example, # if Autokey is disabled on a folder, it can be re-enabled on a sub-folder # or project within that folder by setting a different mode (e.g., # DEDICATED_KEY_PROJECT or RESOURCE_PROJECT). DISABLED = 3 end end |