Class: Google::Cloud::Kms::V1::Digest
- Inherits:
-
Object
- Object
- Google::Cloud::Kms::V1::Digest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/kms/v1/service.rb
Overview
A Digest holds a cryptographic message digest.
Instance Attribute Summary collapse
-
#external_mu ⇒ ::String
A message digest produced with SHAKE-256, to be used with ML-DSA external-μ algorithms only.
-
#sha256 ⇒ ::String
A message digest produced with the SHA-256 algorithm.
-
#sha384 ⇒ ::String
A message digest produced with the SHA-384 algorithm.
-
#sha512 ⇒ ::String
A message digest produced with the SHA-512 algorithm.
Instance Attribute Details
#external_mu ⇒ ::String
Returns A message digest produced with SHAKE-256, to be used with ML-DSA external-μ algorithms only. See "message representative" note in section 6.2, algorithm 7 of the FIPS-204 standard: https://doi.org/10.6028/nist.fips.204
Note: The following fields are mutually exclusive: external_mu, sha256, sha384, sha512. If a field in that set is populated, all other fields in the set will automatically be cleared.
1861 1862 1863 1864 |
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 1861 class Digest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#sha256 ⇒ ::String
Returns A message digest produced with the SHA-256 algorithm.
Note: The following fields are mutually exclusive: sha256, sha384, sha512, external_mu. If a field in that set is populated, all other fields in the set will automatically be cleared.
1861 1862 1863 1864 |
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 1861 class Digest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#sha384 ⇒ ::String
Returns A message digest produced with the SHA-384 algorithm.
Note: The following fields are mutually exclusive: sha384, sha256, sha512, external_mu. If a field in that set is populated, all other fields in the set will automatically be cleared.
1861 1862 1863 1864 |
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 1861 class Digest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#sha512 ⇒ ::String
Returns A message digest produced with the SHA-512 algorithm.
Note: The following fields are mutually exclusive: sha512, sha256, sha384, external_mu. If a field in that set is populated, all other fields in the set will automatically be cleared.
1861 1862 1863 1864 |
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 1861 class Digest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |