Class: Google::Cloud::Kms::V1::EkmService::Rest::Client
- Inherits:
-
Object
- Object
- Google::Cloud::Kms::V1::EkmService::Rest::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/kms/v1/ekm_service/rest/client.rb
Overview
REST client for the EkmService service.
Google Cloud Key Management EKM Service
Manages external cryptographic keys and operations using those keys. Implements a REST model with the following objects:
Defined Under Namespace
Classes: Configuration
Instance Attribute Summary collapse
-
#iam_policy_client ⇒ Google::Iam::V1::IAMPolicy::Rest::Client
readonly
Get the associated client for mix-in of the IAMPolicy.
-
#location_client ⇒ Google::Cloud::Location::Locations::Rest::Client
readonly
Get the associated client for mix-in of the Locations.
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the EkmService Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the EkmService Client instance.
-
#create_ekm_connection(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Kms::V1::EkmConnection
Creates a new EkmConnection in a given Project and Location.
-
#get_ekm_config(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Kms::V1::EkmConfig
Returns the EkmConfig singleton resource for a given project and location.
-
#get_ekm_connection(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Kms::V1::EkmConnection
Returns metadata for a given EkmConnection.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new EkmService REST client object.
-
#list_ekm_connections(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Kms::V1::EkmConnection>
Lists EkmConnections.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#universe_domain ⇒ String
The effective universe domain.
-
#update_ekm_config(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Kms::V1::EkmConfig
Updates the EkmConfig singleton resource for a given project and location.
-
#update_ekm_connection(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Kms::V1::EkmConnection
Updates an EkmConnection's metadata.
-
#verify_connectivity(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Kms::V1::VerifyConnectivityResponse
Verifies that Cloud KMS can successfully connect to the external key manager specified by an EkmConnection.
Methods included from Paths
#ekm_config_path, #ekm_connection_path, #location_path, #service_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new EkmService REST client object.
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/google/cloud/kms/v1/ekm_service/rest/client.rb', line 152 def initialize # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @ekm_service_stub = ::Google::Cloud::Kms::V1::EkmService::Rest::ServiceStub.new( endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, credentials: credentials, logger: @config.logger ) @ekm_service_stub.logger(stub: true)&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end @location_client = Google::Cloud::Location::Locations::Rest::Client.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @ekm_service_stub.endpoint config.universe_domain = @ekm_service_stub.universe_domain config.bindings_override = @config.bindings_override config.logger = @ekm_service_stub.logger if config.respond_to? :logger= end @iam_policy_client = Google::Iam::V1::IAMPolicy::Rest::Client.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @ekm_service_stub.endpoint config.universe_domain = @ekm_service_stub.universe_domain config.bindings_override = @config.bindings_override config.logger = @ekm_service_stub.logger if config.respond_to? :logger= end end |
Instance Attribute Details
#iam_policy_client ⇒ Google::Iam::V1::IAMPolicy::Rest::Client (readonly)
Get the associated client for mix-in of the IAMPolicy.
224 225 226 |
# File 'lib/google/cloud/kms/v1/ekm_service/rest/client.rb', line 224 def iam_policy_client @iam_policy_client end |
#location_client ⇒ Google::Cloud::Location::Locations::Rest::Client (readonly)
Get the associated client for mix-in of the Locations.
217 218 219 |
# File 'lib/google/cloud/kms/v1/ekm_service/rest/client.rb', line 217 def location_client @location_client end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the EkmService Client class.
See Configuration for a description of the configuration fields.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/google/cloud/kms/v1/ekm_service/rest/client.rb', line 70 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "Kms", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.rpcs.list_ekm_connections.timeout = 60.0 default_config.rpcs.list_ekm_connections.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14, 4] } default_config.rpcs.get_ekm_connection.timeout = 60.0 default_config.rpcs.get_ekm_connection.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14, 4] } default_config.rpcs.create_ekm_connection.timeout = 60.0 default_config.rpcs.create_ekm_connection.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14, 4] } default_config.rpcs.update_ekm_connection.timeout = 60.0 default_config.rpcs.update_ekm_connection.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14, 4] } default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the EkmService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
122 123 124 125 |
# File 'lib/google/cloud/kms/v1/ekm_service/rest/client.rb', line 122 def configure yield @config if block_given? @config end |
#create_ekm_connection(request, options = nil) ⇒ ::Google::Cloud::Kms::V1::EkmConnection #create_ekm_connection(parent: nil, ekm_connection_id: nil, ekm_connection: nil) ⇒ ::Google::Cloud::Kms::V1::EkmConnection
Creates a new EkmConnection in a given Project and Location.
476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'lib/google/cloud/kms/v1/ekm_service/rest/client.rb', line 476 def create_ekm_connection request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Kms::V1::CreateEkmConnectionRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_ekm_connection..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Kms::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.create_ekm_connection.timeout, metadata: , retry_policy: @config.rpcs.create_ekm_connection.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @ekm_service_stub.create_ekm_connection request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#get_ekm_config(request, options = nil) ⇒ ::Google::Cloud::Kms::V1::EkmConfig #get_ekm_config(name: nil) ⇒ ::Google::Cloud::Kms::V1::EkmConfig
Returns the EkmConfig singleton resource for a given project and location.
637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 |
# File 'lib/google/cloud/kms/v1/ekm_service/rest/client.rb', line 637 def get_ekm_config request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Kms::V1::GetEkmConfigRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_ekm_config..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Kms::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get_ekm_config.timeout, metadata: , retry_policy: @config.rpcs.get_ekm_config.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @ekm_service_stub.get_ekm_config request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#get_ekm_connection(request, options = nil) ⇒ ::Google::Cloud::Kms::V1::EkmConnection #get_ekm_connection(name: nil) ⇒ ::Google::Cloud::Kms::V1::EkmConnection
Returns metadata for a given EkmConnection.
389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 |
# File 'lib/google/cloud/kms/v1/ekm_service/rest/client.rb', line 389 def get_ekm_connection request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Kms::V1::GetEkmConnectionRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_ekm_connection..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Kms::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get_ekm_connection.timeout, metadata: , retry_policy: @config.rpcs.get_ekm_connection.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @ekm_service_stub.get_ekm_connection request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#list_ekm_connections(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Kms::V1::EkmConnection> #list_ekm_connections(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Kms::V1::EkmConnection>
Lists EkmConnections.
307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/google/cloud/kms/v1/ekm_service/rest/client.rb', line 307 def list_ekm_connections request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Kms::V1::ListEkmConnectionsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_ekm_connections..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Kms::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.list_ekm_connections.timeout, metadata: , retry_policy: @config.rpcs.list_ekm_connections.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @ekm_service_stub.list_ekm_connections request, do |result, operation| result = ::Gapic::Rest::PagedEnumerable.new @ekm_service_stub, :list_ekm_connections, "ekm_connections", request, result, yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
231 232 233 |
# File 'lib/google/cloud/kms/v1/ekm_service/rest/client.rb', line 231 def logger @ekm_service_stub.logger end |
#universe_domain ⇒ String
The effective universe domain
132 133 134 |
# File 'lib/google/cloud/kms/v1/ekm_service/rest/client.rb', line 132 def universe_domain @ekm_service_stub.universe_domain end |
#update_ekm_config(request, options = nil) ⇒ ::Google::Cloud::Kms::V1::EkmConfig #update_ekm_config(ekm_config: nil, update_mask: nil) ⇒ ::Google::Cloud::Kms::V1::EkmConfig
Updates the EkmConfig singleton resource for a given project and location.
718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 |
# File 'lib/google/cloud/kms/v1/ekm_service/rest/client.rb', line 718 def update_ekm_config request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Kms::V1::UpdateEkmConfigRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_ekm_config..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Kms::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.update_ekm_config.timeout, metadata: , retry_policy: @config.rpcs.update_ekm_config.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @ekm_service_stub.update_ekm_config request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#update_ekm_connection(request, options = nil) ⇒ ::Google::Cloud::Kms::V1::EkmConnection #update_ekm_connection(ekm_connection: nil, update_mask: nil) ⇒ ::Google::Cloud::Kms::V1::EkmConnection
Updates an EkmConnection's metadata.
557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 |
# File 'lib/google/cloud/kms/v1/ekm_service/rest/client.rb', line 557 def update_ekm_connection request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Kms::V1::UpdateEkmConnectionRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_ekm_connection..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Kms::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.update_ekm_connection.timeout, metadata: , retry_policy: @config.rpcs.update_ekm_connection.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @ekm_service_stub.update_ekm_connection request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#verify_connectivity(request, options = nil) ⇒ ::Google::Cloud::Kms::V1::VerifyConnectivityResponse #verify_connectivity(name: nil) ⇒ ::Google::Cloud::Kms::V1::VerifyConnectivityResponse
Verifies that Cloud KMS can successfully connect to the external key manager specified by an EkmConnection. If there is an error connecting to the EKM, this method returns a FAILED_PRECONDITION status containing structured information as described at https://cloud.google.com/kms/docs/reference/ekm_errors.
801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 |
# File 'lib/google/cloud/kms/v1/ekm_service/rest/client.rb', line 801 def verify_connectivity request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Kms::V1::VerifyConnectivityRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.verify_connectivity..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Kms::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.verify_connectivity.timeout, metadata: , retry_policy: @config.rpcs.verify_connectivity.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @ekm_service_stub.verify_connectivity request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |