Class: Google::Cloud::Kms::V1::GetImportJobRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Kms::V1::GetImportJobRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/kms/v1/service.rb
Overview
Request message for KeyManagementService.GetImportJob.
Instance Attribute Summary collapse
-
#name ⇒ ::String
Required.
-
#public_key_format ⇒ ::Google::Cloud::Kms::V1::PublicKey::PublicKeyFormat
Optional.
Instance Attribute Details
#name ⇒ ::String
384 385 386 387 |
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 384 class GetImportJobRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#public_key_format ⇒ ::Google::Cloud::Kms::V1::PublicKey::PublicKeyFormat
Returns Optional. Specifies the [WrappingPublicKey][] format. If not specified:
- For RSA-based import methods, the wrapping key will be returned in PEM format
- For pure ML-KEM-based import methods, the wrapping key will be returned in the raw bytes format specified in FIPS-203
- For X-Wing-based import methods, the wrapping key will be returned in the raw bytes format specified in https://datatracker.ietf.org/doc/draft-connolly-cfrg-xwing-kem.
384 385 386 387 |
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 384 class GetImportJobRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |