Class: Google::Cloud::Kms::V1::GetPublicKeyRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Kms::V1::GetPublicKeyRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/kms/v1/service.rb
Overview
Request message for KeyManagementService.GetPublicKey.
Instance Attribute Summary collapse
-
#name ⇒ ::String
Required.
-
#public_key_format ⇒ ::Google::Cloud::Kms::V1::PublicKey::PublicKeyFormat
Optional.
Instance Attribute Details
#name ⇒ ::String
Returns Required. The name of the CryptoKeyVersion public key to get.
362 363 364 365 |
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 362 class GetPublicKeyRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#public_key_format ⇒ ::Google::Cloud::Kms::V1::PublicKey::PublicKeyFormat
Optional. The PublicKey format specified by the user. This field is required for PQC algorithms. If specified, the public key will be exported through the public_key field in the requested format. Otherwise, the pem field will be populated for non-PQC algorithms, and an error will be returned for PQC algorithms.
362 363 364 365 |
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 362 class GetPublicKeyRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |