Class: Google::Cloud::Kms::V1::HsmManagement::Rest::Client
- Inherits:
-
Object
- Object
- Google::Cloud::Kms::V1::HsmManagement::Rest::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/kms/v1/hsm_management/rest/client.rb
Overview
REST client for the HsmManagement service.
Google Cloud HSM Management Service
Provides interfaces for managing HSM instances.
Implements a REST model with the following objects:
Defined Under Namespace
Classes: Configuration
Instance Attribute Summary collapse
-
#iam_policy_client ⇒ Google::Iam::V1::IAMPolicy::Rest::Client
readonly
Get the associated client for mix-in of the IAMPolicy.
-
#location_client ⇒ Google::Cloud::Location::Locations::Rest::Client
readonly
Get the associated client for mix-in of the Locations.
-
#operations_client ⇒ ::Google::Cloud::Kms::V1::HsmManagement::Rest::Operations
readonly
Get the associated client for long-running operations.
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the HsmManagement Client class.
Instance Method Summary collapse
-
#approve_single_tenant_hsm_instance_proposal(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Kms::V1::ApproveSingleTenantHsmInstanceProposalResponse
Approves a SingleTenantHsmInstanceProposal for a given SingleTenantHsmInstance.
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the HsmManagement Client instance.
-
#create_single_tenant_hsm_instance(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Operation
Creates a new SingleTenantHsmInstance in a given Project and Location.
-
#create_single_tenant_hsm_instance_proposal(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Operation
Creates a new SingleTenantHsmInstanceProposal for a given SingleTenantHsmInstance.
-
#delete_single_tenant_hsm_instance_proposal(request, options = nil) {|result, operation| ... } ⇒ ::Google::Protobuf::Empty
Deletes a SingleTenantHsmInstanceProposal.
-
#execute_single_tenant_hsm_instance_proposal(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Operation
Executes a SingleTenantHsmInstanceProposal for a given SingleTenantHsmInstance.
-
#get_single_tenant_hsm_instance(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Kms::V1::SingleTenantHsmInstance
Returns metadata for a given SingleTenantHsmInstance.
-
#get_single_tenant_hsm_instance_proposal(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Kms::V1::SingleTenantHsmInstanceProposal
Returns metadata for a given SingleTenantHsmInstanceProposal.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new HsmManagement REST client object.
- #list_single_tenant_hsm_instance_proposals(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Kms::V1::SingleTenantHsmInstanceProposal>
-
#list_single_tenant_hsm_instances(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Kms::V1::SingleTenantHsmInstance>
Lists SingleTenantHsmInstances.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#universe_domain ⇒ String
The effective universe domain.
Methods included from Paths
#location_path, #single_tenant_hsm_instance_path, #single_tenant_hsm_instance_proposal_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new HsmManagement REST client object.
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/google/cloud/kms/v1/hsm_management/rest/client.rb', line 179 def initialize # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @operations_client = ::Google::Cloud::Kms::V1::HsmManagement::Rest::Operations.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @config.endpoint config.universe_domain = @config.universe_domain end @hsm_management_stub = ::Google::Cloud::Kms::V1::HsmManagement::Rest::ServiceStub.new( endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, credentials: credentials, logger: @config.logger ) @hsm_management_stub.logger(stub: true)&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end @location_client = Google::Cloud::Location::Locations::Rest::Client.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @hsm_management_stub.endpoint config.universe_domain = @hsm_management_stub.universe_domain config.bindings_override = @config.bindings_override config.logger = @hsm_management_stub.logger if config.respond_to? :logger= end @iam_policy_client = Google::Iam::V1::IAMPolicy::Rest::Client.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @hsm_management_stub.endpoint config.universe_domain = @hsm_management_stub.universe_domain config.bindings_override = @config.bindings_override config.logger = @hsm_management_stub.logger if config.respond_to? :logger= end end |
Instance Attribute Details
#iam_policy_client ⇒ Google::Iam::V1::IAMPolicy::Rest::Client (readonly)
Get the associated client for mix-in of the IAMPolicy.
265 266 267 |
# File 'lib/google/cloud/kms/v1/hsm_management/rest/client.rb', line 265 def iam_policy_client @iam_policy_client end |
#location_client ⇒ Google::Cloud::Location::Locations::Rest::Client (readonly)
Get the associated client for mix-in of the Locations.
258 259 260 |
# File 'lib/google/cloud/kms/v1/hsm_management/rest/client.rb', line 258 def location_client @location_client end |
#operations_client ⇒ ::Google::Cloud::Kms::V1::HsmManagement::Rest::Operations (readonly)
Get the associated client for long-running operations.
251 252 253 |
# File 'lib/google/cloud/kms/v1/hsm_management/rest/client.rb', line 251 def operations_client @operations_client end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the HsmManagement Client class.
See Configuration for a description of the configuration fields.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/google/cloud/kms/v1/hsm_management/rest/client.rb', line 72 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "Kms", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.rpcs.list_single_tenant_hsm_instances.timeout = 60.0 default_config.rpcs.list_single_tenant_hsm_instances.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14, 4] } default_config.rpcs.get_single_tenant_hsm_instance.timeout = 60.0 default_config.rpcs.get_single_tenant_hsm_instance.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14, 4] } default_config.rpcs.create_single_tenant_hsm_instance.timeout = 60.0 default_config.rpcs.create_single_tenant_hsm_instance.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14, 4] } default_config.rpcs.create_single_tenant_hsm_instance_proposal.timeout = 60.0 default_config.rpcs.create_single_tenant_hsm_instance_proposal.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14, 4] } default_config.rpcs.approve_single_tenant_hsm_instance_proposal.timeout = 60.0 default_config.rpcs.approve_single_tenant_hsm_instance_proposal.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14, 4] } default_config.rpcs.execute_single_tenant_hsm_instance_proposal.timeout = 60.0 default_config.rpcs.execute_single_tenant_hsm_instance_proposal.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14, 4] } default_config.rpcs.get_single_tenant_hsm_instance_proposal.timeout = 60.0 default_config.rpcs.get_single_tenant_hsm_instance_proposal.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14, 4] } default_config.rpcs.list_single_tenant_hsm_instance_proposals.timeout = 60.0 default_config.rpcs.list_single_tenant_hsm_instance_proposals.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14, 4] } default_config.rpcs.delete_single_tenant_hsm_instance_proposal.timeout = 60.0 default_config.rpcs.delete_single_tenant_hsm_instance_proposal.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [14, 4] } default_config end yield @configure if block_given? @configure end |
Instance Method Details
#approve_single_tenant_hsm_instance_proposal(request, options = nil) ⇒ ::Google::Cloud::Kms::V1::ApproveSingleTenantHsmInstanceProposalResponse #approve_single_tenant_hsm_instance_proposal(name: nil, quorum_reply: nil, required_action_quorum_reply: nil) ⇒ ::Google::Cloud::Kms::V1::ApproveSingleTenantHsmInstanceProposalResponse
Approves a SingleTenantHsmInstanceProposal for a given SingleTenantHsmInstance. The proposal must be in the PENDING state.
739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 |
# File 'lib/google/cloud/kms/v1/hsm_management/rest/client.rb', line 739 def approve_single_tenant_hsm_instance_proposal request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Kms::V1::ApproveSingleTenantHsmInstanceProposalRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.approve_single_tenant_hsm_instance_proposal..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Kms::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.approve_single_tenant_hsm_instance_proposal.timeout, metadata: , retry_policy: @config.rpcs.approve_single_tenant_hsm_instance_proposal.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @hsm_management_stub.approve_single_tenant_hsm_instance_proposal request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#configure {|config| ... } ⇒ Client::Configuration
Configure the HsmManagement Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
149 150 151 152 |
# File 'lib/google/cloud/kms/v1/hsm_management/rest/client.rb', line 149 def configure yield @config if block_given? @config end |
#create_single_tenant_hsm_instance(request, options = nil) ⇒ ::Gapic::Operation #create_single_tenant_hsm_instance(parent: nil, single_tenant_hsm_instance_id: nil, single_tenant_hsm_instance: nil) ⇒ ::Gapic::Operation
Creates a new SingleTenantHsmInstance in a given Project and Location. User must create a RegisterTwoFactorAuthKeys proposal with this single-tenant HSM instance to finish setup of the instance.
538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 |
# File 'lib/google/cloud/kms/v1/hsm_management/rest/client.rb', line 538 def create_single_tenant_hsm_instance request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Kms::V1::CreateSingleTenantHsmInstanceRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_single_tenant_hsm_instance..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Kms::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.create_single_tenant_hsm_instance.timeout, metadata: , retry_policy: @config.rpcs.create_single_tenant_hsm_instance.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @hsm_management_stub.create_single_tenant_hsm_instance request, do |result, operation| result = ::Gapic::Operation.new result, @operations_client, options: yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#create_single_tenant_hsm_instance_proposal(request, options = nil) ⇒ ::Gapic::Operation #create_single_tenant_hsm_instance_proposal(parent: nil, single_tenant_hsm_instance_proposal_id: nil, single_tenant_hsm_instance_proposal: nil) ⇒ ::Gapic::Operation
Creates a new SingleTenantHsmInstanceProposal for a given SingleTenantHsmInstance.
638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 |
# File 'lib/google/cloud/kms/v1/hsm_management/rest/client.rb', line 638 def create_single_tenant_hsm_instance_proposal request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Kms::V1::CreateSingleTenantHsmInstanceProposalRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_single_tenant_hsm_instance_proposal..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Kms::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.create_single_tenant_hsm_instance_proposal.timeout, metadata: , retry_policy: @config.rpcs.create_single_tenant_hsm_instance_proposal.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @hsm_management_stub.create_single_tenant_hsm_instance_proposal request, do |result, operation| result = ::Gapic::Operation.new result, @operations_client, options: yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_single_tenant_hsm_instance_proposal(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_single_tenant_hsm_instance_proposal(name: nil) ⇒ ::Google::Protobuf::Empty
Deletes a SingleTenantHsmInstanceProposal.
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 |
# File 'lib/google/cloud/kms/v1/hsm_management/rest/client.rb', line 1115 def delete_single_tenant_hsm_instance_proposal request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Kms::V1::DeleteSingleTenantHsmInstanceProposalRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_single_tenant_hsm_instance_proposal..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Kms::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.delete_single_tenant_hsm_instance_proposal.timeout, metadata: , retry_policy: @config.rpcs.delete_single_tenant_hsm_instance_proposal.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @hsm_management_stub.delete_single_tenant_hsm_instance_proposal request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#execute_single_tenant_hsm_instance_proposal(request, options = nil) ⇒ ::Gapic::Operation #execute_single_tenant_hsm_instance_proposal(name: nil) ⇒ ::Gapic::Operation
Executes a SingleTenantHsmInstanceProposal for a given SingleTenantHsmInstance. The proposal must be in the APPROVED state.
833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 |
# File 'lib/google/cloud/kms/v1/hsm_management/rest/client.rb', line 833 def execute_single_tenant_hsm_instance_proposal request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Kms::V1::ExecuteSingleTenantHsmInstanceProposalRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.execute_single_tenant_hsm_instance_proposal..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Kms::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.execute_single_tenant_hsm_instance_proposal.timeout, metadata: , retry_policy: @config.rpcs.execute_single_tenant_hsm_instance_proposal.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @hsm_management_stub.execute_single_tenant_hsm_instance_proposal request, do |result, operation| result = ::Gapic::Operation.new result, @operations_client, options: yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#get_single_tenant_hsm_instance(request, options = nil) ⇒ ::Google::Cloud::Kms::V1::SingleTenantHsmInstance #get_single_tenant_hsm_instance(name: nil) ⇒ ::Google::Cloud::Kms::V1::SingleTenantHsmInstance
Returns metadata for a given SingleTenantHsmInstance.
440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 |
# File 'lib/google/cloud/kms/v1/hsm_management/rest/client.rb', line 440 def get_single_tenant_hsm_instance request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Kms::V1::GetSingleTenantHsmInstanceRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_single_tenant_hsm_instance..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Kms::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get_single_tenant_hsm_instance.timeout, metadata: , retry_policy: @config.rpcs.get_single_tenant_hsm_instance.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @hsm_management_stub.get_single_tenant_hsm_instance request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#get_single_tenant_hsm_instance_proposal(request, options = nil) ⇒ ::Google::Cloud::Kms::V1::SingleTenantHsmInstanceProposal #get_single_tenant_hsm_instance_proposal(name: nil) ⇒ ::Google::Cloud::Kms::V1::SingleTenantHsmInstanceProposal
Returns metadata for a given SingleTenantHsmInstanceProposal.
917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 |
# File 'lib/google/cloud/kms/v1/hsm_management/rest/client.rb', line 917 def get_single_tenant_hsm_instance_proposal request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Kms::V1::GetSingleTenantHsmInstanceProposalRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_single_tenant_hsm_instance_proposal..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Kms::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get_single_tenant_hsm_instance_proposal.timeout, metadata: , retry_policy: @config.rpcs.get_single_tenant_hsm_instance_proposal.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @hsm_management_stub.get_single_tenant_hsm_instance_proposal request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#list_single_tenant_hsm_instance_proposals(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Kms::V1::SingleTenantHsmInstanceProposal> #list_single_tenant_hsm_instance_proposals(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil, show_deleted: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Kms::V1::SingleTenantHsmInstanceProposal>
1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/google/cloud/kms/v1/hsm_management/rest/client.rb', line 1031 def list_single_tenant_hsm_instance_proposals request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Kms::V1::ListSingleTenantHsmInstanceProposalsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_single_tenant_hsm_instance_proposals..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Kms::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.list_single_tenant_hsm_instance_proposals.timeout, metadata: , retry_policy: @config.rpcs.list_single_tenant_hsm_instance_proposals.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @hsm_management_stub.list_single_tenant_hsm_instance_proposals request, do |result, operation| result = ::Gapic::Rest::PagedEnumerable.new @hsm_management_stub, :list_single_tenant_hsm_instance_proposals, "single_tenant_hsm_instance_proposals", request, result, yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#list_single_tenant_hsm_instances(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Kms::V1::SingleTenantHsmInstance> #list_single_tenant_hsm_instances(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil, show_deleted: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Kms::V1::SingleTenantHsmInstance>
Lists SingleTenantHsmInstances.
357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 |
# File 'lib/google/cloud/kms/v1/hsm_management/rest/client.rb', line 357 def list_single_tenant_hsm_instances request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Kms::V1::ListSingleTenantHsmInstancesRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_single_tenant_hsm_instances..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Kms::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.list_single_tenant_hsm_instances.timeout, metadata: , retry_policy: @config.rpcs.list_single_tenant_hsm_instances.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @hsm_management_stub.list_single_tenant_hsm_instances request, do |result, operation| result = ::Gapic::Rest::PagedEnumerable.new @hsm_management_stub, :list_single_tenant_hsm_instances, "single_tenant_hsm_instances", request, result, yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
272 273 274 |
# File 'lib/google/cloud/kms/v1/hsm_management/rest/client.rb', line 272 def logger @hsm_management_stub.logger end |
#universe_domain ⇒ String
The effective universe domain
159 160 161 |
# File 'lib/google/cloud/kms/v1/hsm_management/rest/client.rb', line 159 def universe_domain @hsm_management_stub.universe_domain end |