Class: Google::Cloud::Kms::V1::ImportTrustedKeyWrappedCryptoKeyVersionRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Kms::V1::ImportTrustedKeyWrappedCryptoKeyVersionRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/kms/v1/service.rb
Overview
Request message for KeyManagementService.ImportTrustedKeyWrappedCryptoKeyVersion.
Instance Attribute Summary collapse
-
#algorithm ⇒ ::Google::Cloud::Kms::V1::CryptoKeyVersion::CryptoKeyVersionAlgorithm
Required.
-
#crypto_key_version ⇒ ::String
Optional.
-
#importing_key ⇒ ::String
Required.
-
#parent ⇒ ::String
Required.
-
#wrapped_key ⇒ ::String
Required.
Instance Attribute Details
#algorithm ⇒ ::Google::Cloud::Kms::V1::CryptoKeyVersion::CryptoKeyVersionAlgorithm
Returns Required. Required - The algorithm of the key being imported. This does not need to match the version_template of the CryptoKey this version imports into.
648 649 650 651 |
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 648 class ImportTrustedKeyWrappedCryptoKeyVersionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#crypto_key_version ⇒ ::String
Returns Optional. The optional name of an existing CryptoKeyVersion to target for an import operation. If this field is not present, a new CryptoKeyVersion containing the supplied key material is created.
If this field is present, the supplied key material is imported into the existing CryptoKeyVersion. To import into an existing CryptoKeyVersion, the CryptoKeyVersion must be a child of ImportTrustedKeyWrappedCryptoKeyVersionRequest.parent, have been previously created via ImportTrustedKeyWrappedCryptoKeyVersion, and be in DESTROYED or IMPORT_FAILED state. The key material and algorithm must match the previous CryptoKeyVersion exactly if the CryptoKeyVersion has ever contained key material.
648 649 650 651 |
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 648 class ImportTrustedKeyWrappedCryptoKeyVersionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#importing_key ⇒ ::String
Returns Required. Required - the CKV of the trusted key used to import. This can be the name of a CryptoKeyVersion or a CryptoKey.
648 649 650 651 |
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 648 class ImportTrustedKeyWrappedCryptoKeyVersionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
648 649 650 651 |
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 648 class ImportTrustedKeyWrappedCryptoKeyVersionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#wrapped_key ⇒ ::String
Returns Required. The target key pre-wrapped on premises.
648 649 650 651 |
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 648 class ImportTrustedKeyWrappedCryptoKeyVersionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |