Class: Google::Cloud::Kms::V1::ListRetiredResourcesRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Kms::V1::ListRetiredResourcesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/kms/v1/service.rb
Overview
Request message for KeyManagementService.ListRetiredResources.
Instance Attribute Summary collapse
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#page_size ⇒ ::Integer
Returns Optional. Optional limit on the number of RetiredResources to be included in the response. Further RetiredResources can subsequently be obtained by including the ListRetiredResourcesResponse.next_page_token in a subsequent request. If unspecified, the server will pick an appropriate default.
197 198 199 200 |
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 197 class ListRetiredResourcesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. Optional pagination token, returned earlier via ListRetiredResourcesResponse.next_page_token.
197 198 199 200 |
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 197 class ListRetiredResourcesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The project-specific location holding the
RetiredResources, in the format
projects/*/locations/*.
197 198 199 200 |
# File 'proto_docs/google/cloud/kms/v1/service.rb', line 197 class ListRetiredResourcesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |