Class: Google::Cloud::Kms::V1::ListSingleTenantHsmInstancesRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Kms::V1::ListSingleTenantHsmInstancesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/kms/v1/hsm_management.rb
Overview
Request message for HsmManagement.ListSingleTenantHsmInstances.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#order_by ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
-
#show_deleted ⇒ ::Boolean
Optional.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. Only include resources that match the filter in the response. For more information, see Sorting and filtering list results.
587 588 589 590 |
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 587 class ListSingleTenantHsmInstancesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#order_by ⇒ ::String
Returns Optional. Specify how the results should be sorted. If not specified, the results will be sorted in the default order. For more information, see Sorting and filtering list results.
587 588 589 590 |
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 587 class ListSingleTenantHsmInstancesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. Optional limit on the number of SingleTenantHsmInstances to include in the response. Further SingleTenantHsmInstances can subsequently be obtained by including the ListSingleTenantHsmInstancesResponse.next_page_token in a subsequent request. If unspecified, the server will pick an appropriate default.
587 588 589 590 |
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 587 class ListSingleTenantHsmInstancesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. Optional pagination token, returned earlier via ListSingleTenantHsmInstancesResponse.next_page_token.
587 588 589 590 |
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 587 class ListSingleTenantHsmInstancesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The resource name of the location associated with the
SingleTenantHsmInstances to
list, in the format projects/*/locations/*.
587 588 589 590 |
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 587 class ListSingleTenantHsmInstancesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#show_deleted ⇒ ::Boolean
Returns Optional. If set to true, HsmManagement.ListSingleTenantHsmInstances will also return SingleTenantHsmInstances in DELETED state.
587 588 589 590 |
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 587 class ListSingleTenantHsmInstancesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |