Class: Google::Cloud::Kms::V1::SingleTenantHsmInstance
- Inherits:
-
Object
- Object
- Google::Cloud::Kms::V1::SingleTenantHsmInstance
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/kms/v1/hsm_management.rb
Overview
A SingleTenantHsmInstance represents a single-tenant HSM instance. It can be used for creating CryptoKeys with a ProtectionLevel of [HSM_SINGLE_TENANT][CryptoKeyVersion.ProtectionLevel.HSM_SINGLE_TENANT], as well as performing cryptographic operations using keys created within the SingleTenantHsmInstance.
Defined Under Namespace
Modules: State Classes: QuorumAuth
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#delete_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#disable_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#key_portability_enabled ⇒ ::Boolean
Optional.
-
#name ⇒ ::String
Identifier.
-
#quorum_auth ⇒ ::Google::Cloud::Kms::V1::SingleTenantHsmInstance::QuorumAuth
Required.
-
#state ⇒ ::Google::Cloud::Kms::V1::SingleTenantHsmInstance::State
readonly
Output only.
-
#unrefreshed_duration_until_disable ⇒ ::Google::Protobuf::Duration
readonly
Output only.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time at which the SingleTenantHsmInstance was created.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 75 class SingleTenantHsmInstance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for M of N quorum auth. # @!attribute [rw] total_approver_count # @return [::Integer] # Required. The total number of approvers. This is the N value used # for M of N quorum auth. Must be greater than or equal to 3 and less than # or equal to 16. # @!attribute [r] required_approver_count # @return [::Integer] # Output only. The required numbers of approvers. The M value used for M of # N quorum auth. Must be greater than or equal to 2 and less than or equal # to # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance::QuorumAuth#total_approver_count total_approver_count} # - 1. # @!attribute [r] two_factor_public_key_pems # @return [::Array<::String>] # Output only. The public keys associated with the 2FA keys for M of N # quorum auth. class QuorumAuth include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The set of states of a # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance}. module State # Not specified. STATE_UNSPECIFIED = 0 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # being created. CREATING = 1 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # waiting for 2FA keys to be registered. This can be done by calling # {::Google::Cloud::Kms::V1::HsmManagement::Client#create_single_tenant_hsm_instance_proposal CreateSingleTenantHsmInstanceProposal} # with the [RegisterTwoFactorAuthKeys][] operation. PENDING_TWO_FACTOR_AUTH_REGISTRATION = 2 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # ready to use. A # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} # must be in the # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance::State::ACTIVE ACTIVE} state # for all {::Google::Cloud::Kms::V1::CryptoKey CryptoKeys} created within the # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} to # be usable. ACTIVE = 3 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # being disabled. DISABLING = 4 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # disabled. DISABLED = 5 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # being deleted. Requests to the instance will be rejected in this state. DELETING = 6 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} # has been deleted. DELETED = 7 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} # has failed and can not be recovered or used. FAILED = 8 end end |
#delete_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time at which the SingleTenantHsmInstance was deleted.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 75 class SingleTenantHsmInstance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for M of N quorum auth. # @!attribute [rw] total_approver_count # @return [::Integer] # Required. The total number of approvers. This is the N value used # for M of N quorum auth. Must be greater than or equal to 3 and less than # or equal to 16. # @!attribute [r] required_approver_count # @return [::Integer] # Output only. The required numbers of approvers. The M value used for M of # N quorum auth. Must be greater than or equal to 2 and less than or equal # to # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance::QuorumAuth#total_approver_count total_approver_count} # - 1. # @!attribute [r] two_factor_public_key_pems # @return [::Array<::String>] # Output only. The public keys associated with the 2FA keys for M of N # quorum auth. class QuorumAuth include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The set of states of a # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance}. module State # Not specified. STATE_UNSPECIFIED = 0 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # being created. CREATING = 1 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # waiting for 2FA keys to be registered. This can be done by calling # {::Google::Cloud::Kms::V1::HsmManagement::Client#create_single_tenant_hsm_instance_proposal CreateSingleTenantHsmInstanceProposal} # with the [RegisterTwoFactorAuthKeys][] operation. PENDING_TWO_FACTOR_AUTH_REGISTRATION = 2 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # ready to use. A # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} # must be in the # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance::State::ACTIVE ACTIVE} state # for all {::Google::Cloud::Kms::V1::CryptoKey CryptoKeys} created within the # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} to # be usable. ACTIVE = 3 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # being disabled. DISABLING = 4 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # disabled. DISABLED = 5 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # being deleted. Requests to the instance will be rejected in this state. DELETING = 6 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} # has been deleted. DELETED = 7 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} # has failed and can not be recovered or used. FAILED = 8 end end |
#disable_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time at which the instance will be automatically disabled if not refreshed. This field is updated upon creation and after each successful refresh operation and enable. A [RefreshSingleTenantHsmInstance][] operation must be made via a SingleTenantHsmInstanceProposal before this time otherwise the SingleTenantHsmInstance will become disabled.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 75 class SingleTenantHsmInstance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for M of N quorum auth. # @!attribute [rw] total_approver_count # @return [::Integer] # Required. The total number of approvers. This is the N value used # for M of N quorum auth. Must be greater than or equal to 3 and less than # or equal to 16. # @!attribute [r] required_approver_count # @return [::Integer] # Output only. The required numbers of approvers. The M value used for M of # N quorum auth. Must be greater than or equal to 2 and less than or equal # to # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance::QuorumAuth#total_approver_count total_approver_count} # - 1. # @!attribute [r] two_factor_public_key_pems # @return [::Array<::String>] # Output only. The public keys associated with the 2FA keys for M of N # quorum auth. class QuorumAuth include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The set of states of a # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance}. module State # Not specified. STATE_UNSPECIFIED = 0 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # being created. CREATING = 1 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # waiting for 2FA keys to be registered. This can be done by calling # {::Google::Cloud::Kms::V1::HsmManagement::Client#create_single_tenant_hsm_instance_proposal CreateSingleTenantHsmInstanceProposal} # with the [RegisterTwoFactorAuthKeys][] operation. PENDING_TWO_FACTOR_AUTH_REGISTRATION = 2 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # ready to use. A # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} # must be in the # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance::State::ACTIVE ACTIVE} state # for all {::Google::Cloud::Kms::V1::CryptoKey CryptoKeys} created within the # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} to # be usable. ACTIVE = 3 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # being disabled. DISABLING = 4 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # disabled. DISABLED = 5 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # being deleted. Requests to the instance will be rejected in this state. DELETING = 6 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} # has been deleted. DELETED = 7 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} # has failed and can not be recovered or used. FAILED = 8 end end |
#key_portability_enabled ⇒ ::Boolean
Returns Optional. Immutable. Indicates whether key portability is enabled for the SingleTenantHsmInstance. This can only be set at creation time. Key portability features are disabled by default and not yet available in GA.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 75 class SingleTenantHsmInstance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for M of N quorum auth. # @!attribute [rw] total_approver_count # @return [::Integer] # Required. The total number of approvers. This is the N value used # for M of N quorum auth. Must be greater than or equal to 3 and less than # or equal to 16. # @!attribute [r] required_approver_count # @return [::Integer] # Output only. The required numbers of approvers. The M value used for M of # N quorum auth. Must be greater than or equal to 2 and less than or equal # to # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance::QuorumAuth#total_approver_count total_approver_count} # - 1. # @!attribute [r] two_factor_public_key_pems # @return [::Array<::String>] # Output only. The public keys associated with the 2FA keys for M of N # quorum auth. class QuorumAuth include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The set of states of a # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance}. module State # Not specified. STATE_UNSPECIFIED = 0 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # being created. CREATING = 1 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # waiting for 2FA keys to be registered. This can be done by calling # {::Google::Cloud::Kms::V1::HsmManagement::Client#create_single_tenant_hsm_instance_proposal CreateSingleTenantHsmInstanceProposal} # with the [RegisterTwoFactorAuthKeys][] operation. PENDING_TWO_FACTOR_AUTH_REGISTRATION = 2 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # ready to use. A # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} # must be in the # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance::State::ACTIVE ACTIVE} state # for all {::Google::Cloud::Kms::V1::CryptoKey CryptoKeys} created within the # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} to # be usable. ACTIVE = 3 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # being disabled. DISABLING = 4 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # disabled. DISABLED = 5 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # being deleted. Requests to the instance will be rejected in this state. DELETING = 6 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} # has been deleted. DELETED = 7 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} # has failed and can not be recovered or used. FAILED = 8 end end |
#name ⇒ ::String
Returns Identifier. The resource name for this
SingleTenantHsmInstance in
the format projects/*/locations/*/singleTenantHsmInstances/*.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 75 class SingleTenantHsmInstance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for M of N quorum auth. # @!attribute [rw] total_approver_count # @return [::Integer] # Required. The total number of approvers. This is the N value used # for M of N quorum auth. Must be greater than or equal to 3 and less than # or equal to 16. # @!attribute [r] required_approver_count # @return [::Integer] # Output only. The required numbers of approvers. The M value used for M of # N quorum auth. Must be greater than or equal to 2 and less than or equal # to # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance::QuorumAuth#total_approver_count total_approver_count} # - 1. # @!attribute [r] two_factor_public_key_pems # @return [::Array<::String>] # Output only. The public keys associated with the 2FA keys for M of N # quorum auth. class QuorumAuth include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The set of states of a # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance}. module State # Not specified. STATE_UNSPECIFIED = 0 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # being created. CREATING = 1 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # waiting for 2FA keys to be registered. This can be done by calling # {::Google::Cloud::Kms::V1::HsmManagement::Client#create_single_tenant_hsm_instance_proposal CreateSingleTenantHsmInstanceProposal} # with the [RegisterTwoFactorAuthKeys][] operation. PENDING_TWO_FACTOR_AUTH_REGISTRATION = 2 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # ready to use. A # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} # must be in the # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance::State::ACTIVE ACTIVE} state # for all {::Google::Cloud::Kms::V1::CryptoKey CryptoKeys} created within the # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} to # be usable. ACTIVE = 3 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # being disabled. DISABLING = 4 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # disabled. DISABLED = 5 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # being deleted. Requests to the instance will be rejected in this state. DELETING = 6 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} # has been deleted. DELETED = 7 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} # has failed and can not be recovered or used. FAILED = 8 end end |
#quorum_auth ⇒ ::Google::Cloud::Kms::V1::SingleTenantHsmInstance::QuorumAuth
Returns Required. The quorum auth configuration for the SingleTenantHsmInstance.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 75 class SingleTenantHsmInstance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for M of N quorum auth. # @!attribute [rw] total_approver_count # @return [::Integer] # Required. The total number of approvers. This is the N value used # for M of N quorum auth. Must be greater than or equal to 3 and less than # or equal to 16. # @!attribute [r] required_approver_count # @return [::Integer] # Output only. The required numbers of approvers. The M value used for M of # N quorum auth. Must be greater than or equal to 2 and less than or equal # to # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance::QuorumAuth#total_approver_count total_approver_count} # - 1. # @!attribute [r] two_factor_public_key_pems # @return [::Array<::String>] # Output only. The public keys associated with the 2FA keys for M of N # quorum auth. class QuorumAuth include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The set of states of a # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance}. module State # Not specified. STATE_UNSPECIFIED = 0 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # being created. CREATING = 1 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # waiting for 2FA keys to be registered. This can be done by calling # {::Google::Cloud::Kms::V1::HsmManagement::Client#create_single_tenant_hsm_instance_proposal CreateSingleTenantHsmInstanceProposal} # with the [RegisterTwoFactorAuthKeys][] operation. PENDING_TWO_FACTOR_AUTH_REGISTRATION = 2 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # ready to use. A # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} # must be in the # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance::State::ACTIVE ACTIVE} state # for all {::Google::Cloud::Kms::V1::CryptoKey CryptoKeys} created within the # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} to # be usable. ACTIVE = 3 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # being disabled. DISABLING = 4 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # disabled. DISABLED = 5 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # being deleted. Requests to the instance will be rejected in this state. DELETING = 6 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} # has been deleted. DELETED = 7 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} # has failed and can not be recovered or used. FAILED = 8 end end |
#state ⇒ ::Google::Cloud::Kms::V1::SingleTenantHsmInstance::State (readonly)
Returns Output only. The state of the SingleTenantHsmInstance.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 75 class SingleTenantHsmInstance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for M of N quorum auth. # @!attribute [rw] total_approver_count # @return [::Integer] # Required. The total number of approvers. This is the N value used # for M of N quorum auth. Must be greater than or equal to 3 and less than # or equal to 16. # @!attribute [r] required_approver_count # @return [::Integer] # Output only. The required numbers of approvers. The M value used for M of # N quorum auth. Must be greater than or equal to 2 and less than or equal # to # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance::QuorumAuth#total_approver_count total_approver_count} # - 1. # @!attribute [r] two_factor_public_key_pems # @return [::Array<::String>] # Output only. The public keys associated with the 2FA keys for M of N # quorum auth. class QuorumAuth include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The set of states of a # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance}. module State # Not specified. STATE_UNSPECIFIED = 0 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # being created. CREATING = 1 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # waiting for 2FA keys to be registered. This can be done by calling # {::Google::Cloud::Kms::V1::HsmManagement::Client#create_single_tenant_hsm_instance_proposal CreateSingleTenantHsmInstanceProposal} # with the [RegisterTwoFactorAuthKeys][] operation. PENDING_TWO_FACTOR_AUTH_REGISTRATION = 2 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # ready to use. A # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} # must be in the # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance::State::ACTIVE ACTIVE} state # for all {::Google::Cloud::Kms::V1::CryptoKey CryptoKeys} created within the # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} to # be usable. ACTIVE = 3 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # being disabled. DISABLING = 4 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # disabled. DISABLED = 5 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # being deleted. Requests to the instance will be rejected in this state. DELETING = 6 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} # has been deleted. DELETED = 7 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} # has failed and can not be recovered or used. FAILED = 8 end end |
#unrefreshed_duration_until_disable ⇒ ::Google::Protobuf::Duration (readonly)
Returns Output only. The system-defined duration that an instance can remain unrefreshed until it is automatically disabled. This will have a value of 120 days.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 75 class SingleTenantHsmInstance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for M of N quorum auth. # @!attribute [rw] total_approver_count # @return [::Integer] # Required. The total number of approvers. This is the N value used # for M of N quorum auth. Must be greater than or equal to 3 and less than # or equal to 16. # @!attribute [r] required_approver_count # @return [::Integer] # Output only. The required numbers of approvers. The M value used for M of # N quorum auth. Must be greater than or equal to 2 and less than or equal # to # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance::QuorumAuth#total_approver_count total_approver_count} # - 1. # @!attribute [r] two_factor_public_key_pems # @return [::Array<::String>] # Output only. The public keys associated with the 2FA keys for M of N # quorum auth. class QuorumAuth include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The set of states of a # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance}. module State # Not specified. STATE_UNSPECIFIED = 0 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # being created. CREATING = 1 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # waiting for 2FA keys to be registered. This can be done by calling # {::Google::Cloud::Kms::V1::HsmManagement::Client#create_single_tenant_hsm_instance_proposal CreateSingleTenantHsmInstanceProposal} # with the [RegisterTwoFactorAuthKeys][] operation. PENDING_TWO_FACTOR_AUTH_REGISTRATION = 2 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # ready to use. A # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} # must be in the # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance::State::ACTIVE ACTIVE} state # for all {::Google::Cloud::Kms::V1::CryptoKey CryptoKeys} created within the # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} to # be usable. ACTIVE = 3 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # being disabled. DISABLING = 4 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # disabled. DISABLED = 5 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} is # being deleted. Requests to the instance will be rejected in this state. DELETING = 6 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} # has been deleted. DELETED = 7 # The # {::Google::Cloud::Kms::V1::SingleTenantHsmInstance SingleTenantHsmInstance} # has failed and can not be recovered or used. FAILED = 8 end end |