Class: Google::Cloud::Kms::V1::SingleTenantHsmInstance::QuorumAuth
- Inherits:
-
Object
- Object
- Google::Cloud::Kms::V1::SingleTenantHsmInstance::QuorumAuth
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/kms/v1/hsm_management.rb
Overview
Configuration for M of N quorum auth.
Instance Attribute Summary collapse
-
#required_approver_count ⇒ ::Integer
readonly
Output only.
-
#total_approver_count ⇒ ::Integer
Required.
-
#two_factor_public_key_pems ⇒ ::Array<::String>
readonly
Output only.
Instance Attribute Details
#required_approver_count ⇒ ::Integer (readonly)
Returns Output only. The required numbers of approvers. The M value used for M of N quorum auth. Must be greater than or equal to 2 and less than or equal to total_approver_count
- 1.
96 97 98 99 |
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 96 class QuorumAuth include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#total_approver_count ⇒ ::Integer
Returns Required. The total number of approvers. This is the N value used for M of N quorum auth. Must be greater than or equal to 3 and less than or equal to 16.
96 97 98 99 |
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 96 class QuorumAuth include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#two_factor_public_key_pems ⇒ ::Array<::String> (readonly)
Returns Output only. The public keys associated with the 2FA keys for M of N quorum auth.
96 97 98 99 |
# File 'proto_docs/google/cloud/kms/v1/hsm_management.rb', line 96 class QuorumAuth include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |